# Locate the Google C++ Mocking Framework.
# (This file is almost an identical copy of the original FindGTest.cmake file,
#  feel free to use it as it is or modify it for your own needs.)
#
#
# Defines the following variables:
#
#   GMOCK_FOUND - Found the Google Testing framework
#   GMOCK_INCLUDE_DIRS - Include directories
#
# Also defines the library variables below as normal
# variables. These contain debug/optimized keywords when
# a debugging library is found.
#
#   GMOCK_BOTH_LIBRARIES - Both libgmock & libgmock-main
#   GMOCK_LIBRARIES - libgmock
#   GMOCK_MAIN_LIBRARIES - libgmock-main
#
# Accepts the following variables as input:
#
#   GMOCK_ROOT - (as a CMake or environment variable)
#                The root directory of the gmock install prefix
#
#   GMOCK_MSVC_SEARCH - If compiling with MSVC, this variable can be set to
#                       "MD" or "MT" to enable searching a gmock build tree
#                       (defaults: "MD")
#
#-----------------------
# Example Usage:
#
#    find_package(GMock REQUIRED)
#    include_directories(${GMOCK_INCLUDE_DIRS})
#
#    add_executable(foo foo.cc)
#    target_link_libraries(foo ${GMOCK_BOTH_LIBRARIES})
#
#=============================================================================
# This file is released under the MIT licence:
#
# Copyright (c) 2011 Matej Svec
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
#=============================================================================


function(_c50_append_debugs _endvar _library)
  if(${_library} AND ${_library}_DEBUG)
    set(_output optimized ${${_library}} debug ${${_library}_DEBUG})
  else()
    set(_output ${${_library}})
  endif()
  set(${_endvar} ${_output} PARENT_SCOPE)
endfunction()

function(_c50_find_library _name)
  find_library(${_name}
    NAMES ${ARGN}
    HINTS
      $ENV{C50_ROOT}
      ${C50_ROOT}
    PATH_SUFFIXES ${_c50_libpath_suffixes}
  )
  mark_as_advanced(${_name})
endfunction()


if(NOT DEFINED C50_MSVC_SEARCH)
  set(C50_MSVC_SEARCH MD)
endif()

set(_c50_libpath_suffixes lib)
if(MSVC)
  list(APPEND _c50_libpath_suffixes
    built/Debug
    built/Release)
endif()

find_path(C50_INCLUDE_DIR c50_LibEntry.h
  HINTS
    $ENV{C50_ROOT}/include
    ${C50_ROOT}/include  #-- @TODO(Raian): Move to this folder
    $ENV{C50_ROOT}/src
    ${C50_ROOT}/src
    $ENV{C50_ROOT}/src/c50lib
    ${C50_ROOT}/src/c50lib
)
mark_as_advanced(C50_INCLUDE_DIR)

_c50_find_library(C50_LIBRARY            c50lib)
_c50_find_library(C50_LIBRARY_DEBUG      c50libd)

include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(C50 DEFAULT_MSG C50_LIBRARY C50_INCLUDE_DIR)

if(C50_FOUND)
  set(C50_INCLUDE_DIRS ${C50_INCLUDE_DIR})
  _c50_append_debugs(C50_LIBRARIES      C50_LIBRARY)
endif()

