#  Find useful TerraLib paths.
#
#  Authors: Raian Vargas Maretto <raian@dpi.inpe.br>
#           Thales Sehn Korting <tkorting@dpi.inpe.br>
#           Emiliano Ferreira Castejon <castejon@dpi.inpe.br>
#

# ----------------------------------------------------------------------------
# Usage:
# In your CMakeLists.txt file do something like this:
# ...
# # TerraLib Useful Paths
# FIND_PACKAGE(TerraLibPaths)
# ...
# if( NOT terralib_PATHS_FOUND )
#   set(terralib_ROOT ${terralib_DIR}/../../
#               CACHE PATH "Path to the directory where TerraLib 5 is installed.")
#   set(TERRALIB_GDAL_DATA_DIR <PATH_TO_GDAL_DATA>
#                CACHE PATH "Path to GDAL Data Directory.")
# endif( terralib_ROOT_FOUND )
# ...
# ----------------------------------------------------------------------------
# IMPORTANT - You may need to manually set:
#  HINTS in lines 37 - path to the TerraLib root directory.
#
# ----------------------------------------------------------------------------
# The following variables are set if TerraLib Paths are found:
#  terralib_PATHS_FOUND     - Set to true when TerraLib paths are found.
#  terralib_ROOT            - TerraLib Root directory
#  TERRALIB_GDAL_DATA_DIR   - GDAL Data Directory
#   

cmake_minimum_required(VERSION 3.1.3 FATAL_ERROR)

find_path(terralib_ROOT
    NAMES share/terralib
    HINTS ${terralib_DIR}/../
          ${terralib_DIR}/../../
)

find_path(TERRALIB_GDAL_DATA_DIR
    NAMES epsg.wkt elipsoid.csv gdal_datum.csv
    HINTS ${terralib_DEPENDENCIES_DIR}/data
          ${terralib_ROOT}/share/data
          ${terralib_DIR}/../share/data
          ${terralib_DIR}/../../share/data
)

if(terralib_ROOT AND TERRALIB_GDAL_DATA_DIR)
    set(terralib_PATHS_FOUND true)
else()
    set(terralib_PATHS_FOUND false)
    message("TerraLib Useful Paths not found")
endif()

mark_as_advanced(terralib_ROOT TERRALIB_GDAL_DATA_DIR)