/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/abstractAction.cpp

  \brief

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib includes
#include <terralib/qt/af/events/LayerEvents.h>

// STL Includes
#include <cassert>
#include <list>
#include <string>

//  GeoDMA includes
#include "geodma_tvplugin/abstractAction.hpp"


gdma::tvplg::AbstractAction::AbstractAction(QMenu* menu) : m_menu(menu), m_action(0) {
}


gdma::tvplg::AbstractAction::~AbstractAction() {
}

void gdma::tvplg::AbstractAction::createAction(std::string name, std::string pixmap) {
    assert(m_menu);

    m_action = new QAction(m_menu);

    m_action->setText(name.c_str());

    if (!pixmap.empty())
        m_action->setIcon(QIcon::fromTheme(pixmap.c_str()));

    connect(m_action, SIGNAL(triggered(bool)), this, SLOT(onActionActivated(bool)));

    m_menu->addAction(m_action);
}

void gdma::tvplg::AbstractAction::addNewLayer(te::map::AbstractLayerPtr layer) {
    te::qt::af::evt::LayerAdded evt(layer.get());
    emit triggered(&evt);
}

std::list<te::map::AbstractLayerPtr> gdma::tvplg::AbstractAction::getLayers() {
    te::qt::af::evt::GetAvailableLayers e;
    te::qt::af::evt::GetLayerSelected ed;

    emit triggered(&e);
    emit triggered(&ed);

    std::list<te::map::AbstractLayerPtr> allLayers = e.m_layers;
    std::list<te::map::AbstractLayerPtr> layers;

    for (auto layer : allLayers) {
        if (layer->isValid())
            layers.push_back(layer);
    }

    te::map::AbstractLayerPtr selectedlayer = ed.m_layer;

    if (!selectedlayer || !selectedlayer->isValid())
        return layers;

    std::list<te::map::AbstractLayerPtr> result;

    result.push_back(selectedlayer);

    for (auto mlayer : layers) {
        if (mlayer->getId() != selectedlayer->getId())
            result.push_back(mlayer);
    }

    return result;
}
