/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/abstractAction.hpp

  \brief

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_ABSTRACTACTIONACTION_HPP_
#define GEODMA_TVPLUGIN_ABSTRACTACTIONACTION_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/af/events/LayerEvents.h>

// Qt Includes
#include <QAction>
#include <QMenu>

// STL
#include <string>
#include <list>

namespace gdma {
namespace tvplg {

/*!
  \class AbstractAction

  \brief This is an abstract class used to register actions into GeoDMA pluging.

*/
class AbstractAction : public QObject {
    Q_OBJECT

 public:
     /*!
       \brief Constructor.

       \param menu The parent menu object.
     */
    explicit AbstractAction(QMenu* menu);

    /*!
      \brief Destructor.
    */
    ~AbstractAction();

 protected slots:  //NOLINT
    /*!
      \brief Slot function used when a action was selected.
      \param checked Flag used in case a toggle action.
    */
    virtual void onActionActivated(bool checked) = 0;

 protected:
    /*!
      \brief Create and set the actions parameters.
      \param name The action name.
      \param pixmap The action pixmap name.
    */
    void createAction(std::string name, std::string pixmap = "");

    /*!
      \brief Add a new layer into layer explorer widget
      \param layer The layer auto pointer
    */
    void addNewLayer(te::map::AbstractLayerPtr layer);

    /*!
      \brief Get the list of layers from app
      \return The list of layer auto pointers
    */
    std::list<te::map::AbstractLayerPtr> getLayers();

    Q_SIGNALS:
    void triggered(te::qt::af::evt::Event* e);

 public:
    QAction* getAction() {
        return m_action;
    }

 protected:
    QMenu* m_menu;            //!< Parent Menu
    QAction* m_action;        //!< Action used to call the process.
};
}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_ABSTRACTACTIONACTION_HPP_
