/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/sampleSelectionAction.cpp

  \brief This file contains the SampleSelectionAction implementation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib includes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/af/ApplicationController.h>
#include <terralib/qt/af/BaseApplication.h>
#include <terralib/qt/af/events/LayerEvents.h>

// Qt Includes
#include <QAction>
#include <QDialog>
#include <QMenu>
#include <QObject>

// STL Includes
#include <memory>

// GeoDMA Includes
#include "geodma_tvplugin/classification/kmeansClassificationAction.hpp"
#include "geodmalib/guicomponents/kmeans/kmeansClassificationDialog.hpp"

gdma::tvplg::KMeansClassificationAction::KMeansClassificationAction(QMenu* menu) :
    gdma::tvplg::AbstractAction(menu) {
    createAction(tr("K-Means Clustering").toUtf8().data(), "k_means");
    m_action->setObjectName("Plugins.GeoDMA.KMeans");
}


gdma::tvplg::KMeansClassificationAction::~KMeansClassificationAction() {
}

void gdma::tvplg::KMeansClassificationAction::onActionActivated(bool) {
    QWidget* parent = te::qt::af::AppCtrlSingleton::getInstance().getMainWindow();

    gdma::guicmp::KMeansClassificationDialog dlg(parent);

    dlg.setLayers(this->getLayers());

    if (dlg.exec() != QDialog::Accepted)
        return;

    if (dlg.newLayerCreated())
        addNewLayer(dlg.getCurrentLayer());
}
