/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
\file gdma/lib/featureextraction/config.h

\brief Configuration flags for the GeoDMA Feature Extraction Runtime module.

\author Raian Vargas Maretto
\author Thales Sehn Korting
\author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_INTERNAL_CONFIG_HPP_
#define GEODMA_TVPLUGIN_INTERNAL_CONFIG_HPP_

#define GDMA_TVPLG_MODULE_NAME "gdma.tvplg"

/** @name DLL/LIB Module
*  Flags for building GeoDMA as a DLL or as a Static Library
*/
//@{

/*!
\def GDMATVPLGEXPORT

\brief You can use this macro in order to export/import classes and functions from this module.

\note If you want to compile TerraLib as DLL in Windows, remember to insert GDMATVPLGDLL into the
project's list of defines.

\note If you want to compile GeoDMA Data Manager Library as an Static Library under Windows,
remember to insert the GDMATVPLGSTATIC flag into the project list of defines.
*/
#ifdef WIN32

#ifdef GDMATVPLGSTATIC
#define GDMATVPLGEXPORT                          // Don't need to export/import... it is a static
// library
#elif GDMATVPLGDLL
#define GDMATVPLGEXPORT  __declspec(dllexport)   // export DLL information
#else
#define GDMATVPLGEXPORT  __declspec(dllimport)   // import DLL information
#endif
#else
#define GDMATVPLGEXPORT
#endif

//@}

#endif  // GEODMA_TVPLUGIN_INTERNAL_CONFIG_HPP_
