/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/featureExtractionAction.cpp

  \brief

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib includes
#include <terralib/qt/af/ApplicationController.h>
#include <terralib/maptools/AbstractLayer.h>

// Qt Includes
#include <QObject>
#include <QMessageBox>

// GeoDMA includes
#include "geodma_tvplugin/featureExtractionAction.hpp"
#include "geodma_tvplugin/featureExtractionDialog.hpp"

gdma::tvplg::FeatureExtractionAction::FeatureExtractionAction(QMenu* menu) :
    gdma::tvplg::AbstractAction(menu) {
    // @TODO:(RAIAN) Verificar como pode ser definido o caminho para o icone
    createAction(tr("Feature Extraction").toUtf8().data(), "attributefill-raster2vector-icon");
    m_action->setObjectName("Plugins.GeoDMA.Feature Extraction");
}


gdma::tvplg::FeatureExtractionAction::~FeatureExtractionAction() {
}

void gdma::tvplg::FeatureExtractionAction::onActionActivated(bool) {
    QWidget* parent = te::qt::af::AppCtrlSingleton::getInstance().getMainWindow();
    gdma::tvplg::FeatureExtractionDialog dlg(parent);

    dlg.setLayers(this->getLayers());

    if (dlg.exec() != QDialog::Accepted)
        return;

    // Adding generated layer
    te::map::AbstractLayerPtr layer = dlg.getOutputLayer();

    if( layer.get() == 0 )
    {
      QMessageBox::critical(parent, tr("GeoDMA Feature Extraction"),
        tr("Features extraction error") );
      return;
    }

    addNewLayer(layer);
}
