/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/FeatureExtractionController.hpp

  \brief This file contains ...

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_FEATUREEXTRACTIONCONTROLLER_HPP_
#define GEODMA_TVPLUGIN_FEATUREEXTRACTIONCONTROLLER_HPP_

// TerraLib includes
#include <terralib/maptools/AbstractLayer.h>

// Boost Includes
#include <boost/filesystem.hpp>

// STL includes
#include <list>
#include <memory>
#include <string>

// GeoDMA includes
#include "geodma_tvplugin/config.hpp"

namespace gdma {
namespace tvplg {

class FeatureExtractionController {
 public:
    FeatureExtractionController();

    ~FeatureExtractionController();

    void setLayersNames(std::list<te::map::AbstractLayerPtr> &layers);

    te::map::AbstractLayerPtr getOutputLayer();

    std::list<te::map::AbstractLayerPtr> &getRasterLayersNames();

    std::list<te::map::AbstractLayerPtr> &getVectorLayersNames();

    void setExecuter(gdma::tvplg::FeatureExtractionController &controller);

    void setSelectedDataLayer(std::string layerID);

    void setSelectedTargetLayer(std::string layerID);

    void setOutputDataset(boost::filesystem::path outputDataset, bool saveSHP);

    void setOutputLayerName(std::string outputLayerName);

    void setOutputCSV(std::string outputCSV);

    void setNoDataValue(double value);

    double getNoDataValue();

    void createOutputLayer();

    virtual bool computeFeatures() = 0;

    bool getUpdateDataSource();

    void setUpdateDataSource(bool update);

 protected:
    // Available Data
    std::list<te::map::AbstractLayerPtr> m_layers;             //!< List of available layers
    std::list<te::map::AbstractLayerPtr> m_rasterLayersNames;  //!< List of available Raster layers
    std::list<te::map::AbstractLayerPtr> m_vectorLayersNames;  //!< List of available Vector layers

    // Inputs
    te::map::AbstractLayerPtr m_layerData;                    //!< Raster/Classified Layer
    te::map::AbstractLayerPtr m_layerTarget;                  //!< Target Layer

    // Outputs
    std::string m_outputLayerName;                            //!< Name of the layer to be generated
    boost::filesystem::path m_outputDataSet;                  //!< Name of the output dataset
    std::string m_outputCSV;                                  //!< Path to the output CSV file
    double m_noDataValue;
    te::map::AbstractLayerPtr m_outputLayer;                  //!< Output Layer

    // Control flags
    bool m_saveCSV;
    bool m_saveSHP;
    bool m_updateDataSource;
};
}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_FEATUREEXTRACTIONCONTROLLER_HPP_
