/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/geodmaPluginDialog.hpp

  \brief This file contains ...

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_FEATUREEXTRACTIONDIALOG_HPP_
#define GEODMA_TVPLUGIN_FEATUREEXTRACTIONDIALOG_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>

// Qt Includes
#include <QDialog>

// STL Includes
#include <list>
#include <map>
#include <memory>
#include <vector>

// GeoDMA Includes
#include "geodma_tvplugin/config.hpp"
#include "geodma_tvplugin/featureExtractionController.hpp"

namespace Ui { class FeatureExtractionDialogForm; }

namespace gdma {
namespace tvplg {
class GDMATVPLGEXPORT FeatureExtractionDialog : public QDialog {
    Q_OBJECT

 public:
    explicit FeatureExtractionDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~FeatureExtractionDialog();

    /*!
      \brief Set the layer that can be used
      \param layers  List of AbstractLayerPtr
    */
    void setLayers(std::list<te::map::AbstractLayerPtr> layers);

    te::map::AbstractLayerPtr getOutputLayer();

 private slots:  //NOLINT
    void onRasterComboBoxSelected(int index);
    void onVectorComboBoxSelected(int index);

    void onClassVectorComboBoxChanged(int index);
    void onColumnComboBoxChanged(int index);

    void onSHPTargetFileToolButtonPressed();
    void onCSVTargetFileToolButtonPressed();
    void onOkPushButtonClicked();
    void onCancelPushButtonClicked();
    void onTargetDatasourceToolButtonPressed();
    void onKindOfFeatTabChanged(int);
    void onBandsSelectedChanged();
    void onKindCheckBoxChanged();
    void onNewLayerNameLineEditEdited();

    void onNoDataLineEditChanged();

 private:
    std::unique_ptr<Ui::FeatureExtractionDialogForm> m_ui;   //!< User interface
    QString m_dialogTitle;                                   //!< Title of the windows

    //!< Internal controllers
    std::map<int, std::shared_ptr<gdma::tvplg::FeatureExtractionController>> m_controllers;
};
}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_FEATUREEXTRACTIONDIALOG_HPP_
