/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/plugin.hpp

  \brief

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_INTERNAL_PLUGIN_HPP_
#define GEODMA_TVPLUGIN_INTERNAL_PLUGIN_HPP_

// TerraLib Includes
#include <terralib/core/plugin/CppPlugin.h>
#include <terralib/qt/af/events/Event.h>

// Qt Includes
#include <QAction>
#include <QMenu>

// GeoDMA Includes
#include "geodma_tvplugin/config.hpp"
#include "geodma_tvplugin/classification/c50ClassificationAction.hpp"
#include "geodma_tvplugin/classification/kmeansClassificationAction.hpp"
#include "geodma_tvplugin/featureExtractionAction.hpp"
#include "geodma_tvplugin/helpAction.hpp"
#include "geodma_tvplugin/sampleSelectionAction.hpp"


namespace gdma {
namespace tvplg {
class Plugin : public QObject, public te::core::CppPlugin {
    Q_OBJECT

 public:
    explicit Plugin(const te::core::PluginInfo& pluginInfo);

    ~Plugin();

    void startup();

    void shutdown();

 protected:
    /*!
      \brief Function used to register all GeoDMA actions.
    */
    void registerActions();

    /*!
      \brief Function used to unregister all GeoDMA actions.
    */
    void unRegisterActions();

 Q_SIGNALS:
    void triggered(te::qt::af::evt::Event* e);

 protected:
    QMenu* m_GeoDMAMenu;                              //!< GeoDMA Menu registered.
    QMenu* m_classificationMenu;                      //!< Classification Menu registered
    QAction* m_classifPopupAction;                    //!< Classification pop up action registered.

    FeatureExtractionAction* m_featureExtractionAction;        //!< Feature Extraction Action
    SampleSelectionAction* m_samplesSelectionAction;           //!< Samples Selection Action
    C50ClassificationAction* m_c50ClassificationAction;        //!< C5.0 Classification Action
    KMeansClassificationAction* m_kmeansClassificationAction;  //!< K-Means Classification Action
    HelpAction* m_helpAction;                                  //!< Help Action
};

}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_INTERNAL_PLUGIN_HPP_
