/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/sampleSelectionAction.cpp

  \brief This file contains the SampleSelectionAction implementation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib includes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/af/ApplicationController.h>
#include <terralib/qt/af/BaseApplication.h>
#include <terralib/qt/af/events/LayerEvents.h>

// Qt Includes
#include <QAction>
#include <QDialog>
#include <QMenu>
#include <QObject>

// STL Includes
#include <memory>

// GeoDMA Includes
#include "geodma_tvplugin/sampleSelectionAction.hpp"
#include "geodma_tvplugin/sampleSelectionDialog.hpp"
#include "geodmalib/guicomponents/sampleSelectionWidget.hpp"

gdma::tvplg::SampleSelectionAction::SampleSelectionAction(QMenu* menu) :
    gdma::tvplg::AbstractAction(menu) {
    // @TODO:(RAIAN) Verificar como pode ser definido o caminho para o icone
    createAction(tr("Sample Selection").toUtf8().data(), "wand");
    m_action->setObjectName("Plugins.GeoDMA.Sample Selection");
}


gdma::tvplg::SampleSelectionAction::~SampleSelectionAction() {
}

void gdma::tvplg::SampleSelectionAction::onActionActivated(bool) {
    te::qt::af::BaseApplication* parent = dynamic_cast<te::qt::af::BaseApplication*>(
        te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());

    m_dialog.reset(new gdma::tvplg::SampleSelectionDialog(
        te::qt::af::AppCtrlSingleton::getInstance().getMainWindow()));

    // Register the application framework listener
    te::qt::af::AppCtrlSingleton::getInstance().addListener(this, te::qt::af::RECEIVER);
    connect(m_dialog.get(), SIGNAL(closeTool()), this, SLOT(onSampleSelectionFinished()));

    // m_dialog->setAttribute(Qt::WA_DeleteOnClose);
    m_dialog->setMapDisplay(parent->getMapDisplay());
    m_dialog->setLayers(this->getLayers());
    m_dialog->show();

    QActionGroup* m_mapEditionTools = te::qt::af::AppCtrlSingleton::getInstance()
        .findActionGroup("Map.ToolsGroup");
    assert(m_mapEditionTools);
    m_dialog->setActionGroup(m_mapEditionTools);
}

void gdma::tvplg::SampleSelectionAction::onSampleSelectionFinished() {
    te::qt::af::AppCtrlSingleton::getInstance().removeListener(this);
    m_dialog.reset(0);
}

void gdma::tvplg::SampleSelectionAction::onApplicationTriggered(te::qt::af::evt::Event* e) {
    switch (e->m_id) {
    // @TODO(Raian): In the zoom with extent, there is some problems. The painted polygons does
    // not appear while drawing the extent. The same with the selection by extent.
    // Verify includes added in the last commit. REMOVE THE UNNECESSARY.
    case te::qt::af::evt::DRAWING_FINISHED :
        m_dialog->drawSamples();
        break;
    default:
        break;
    }
}
