/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/sampleSelectionAction.hpp

  \brief This file contains the SampleSelectionAction class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_SAMPLESELECTIONACTION_HPP_
#define GEODMA_TVPLUGIN_SAMPLESELECTIONACTION_HPP_

// TerraLib Includes
#include <terralib/qt/af/events/LayerEvents.h>

// Qt Includes
#include <QAction>
#include <QMenu>

// STL Includes
#include <memory>

// GeoDMA Includes
#include "geodma_tvplugin/abstractAction.hpp"
#include "geodma_tvplugin/config.hpp"
#include "geodma_tvplugin/sampleSelectionDialog.hpp"

namespace gdma {
namespace tvplg {
/*!
  \class SampleSelectionAction

  \brief This class register the Sample Selection action into GeoDMA Plugin.
*/
class GDMATVPLGEXPORT SampleSelectionAction : public AbstractAction {
    Q_OBJECT
 public:
    explicit SampleSelectionAction(QMenu* menu);

    ~SampleSelectionAction();

 protected slots:  //NOLINT
    virtual void onActionActivated(bool checked);
    virtual void onSampleSelectionFinished();
    void onApplicationTriggered(te::qt::af::evt::Event* e);

 private:
    std::unique_ptr<gdma::tvplg::SampleSelectionDialog> m_dialog;
};
}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_SAMPLESELECTIONACTION_HPP_
