/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/sampleSelectionDialog.hpp

  \brief This file contains the SampleSelectionDialog class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_SAMPLESELECTIONDIALOG_HPP_
#define GEODMA_TVPLUGIN_SAMPLESELECTIONDIALOG_HPP_

// TerraLib inlcludes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/widgets/canvas/MapDisplay.h>
#include <terralib/qt/widgets/progress/ProgressViewerDialog.h>

// Qt Includes
#include <QDialog>

// STL Includes
#include <list>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/sampleSelectionWidget.hpp"
#include "geodma_tvplugin/config.hpp"

namespace Ui { class SampleSelectionDialogForm; }

namespace gdma {
namespace tvplg {
class GDMATVPLGEXPORT SampleSelectionDialog : public QDialog {
    Q_OBJECT

 public:
     explicit SampleSelectionDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~SampleSelectionDialog();

    /*!
      \brief Set the layer that can be used
      \param layers  List of AbstractLayerPtr
    */
    void setLayers(std::list<te::map::AbstractLayerPtr> layers);

    /*!
      \brief This method is used to set the map display
      \param[in] The current map display of the application.
    */
    void setMapDisplay(te::qt::widgets::MapDisplay* mapDisplay);

    /*!
      \brief This method is used to configure the actions to interact with the map display
      \param[in] The action tools necessary to the interactions.
    */
    void setActionGroup(QActionGroup* actionGroup);

    void clearCanvas();

    void closeEvent(QCloseEvent* e);

    void drawSamples();

 signals:
    void closeTool();

 public slots: //NOLINT
    void onOkPushButtonClicked();
    void onCancelPushButtonClicked();

 private:
     std::unique_ptr<Ui::SampleSelectionDialogForm> m_ui;
     std::unique_ptr<gdma::guicmp::SampleSelectionWidget> m_sampleSelWidget;

     std::string m_dialogTitle;
     int m_msgObsId;
     int m_progId;
     std::unique_ptr<te::qt::widgets::ProgressViewerDialog> m_progViewer;
};
}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_SAMPLESELECTIONDIALOG_HPP_
