/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
\file gdma/geodma_tvplugin/spectralAndSpatialFeaturesController.hpp

\brief This file contains ...

\author Raian Vargas Maretto
\author Thales Sehn Korting
\author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_SPECTRALANDSPATIALFEATURESCONTROLLER_HPP_
#define GEODMA_TVPLUGIN_SPECTRALANDSPATIALFEATURESCONTROLLER_HPP_

// TerraLib includes
#include <terralib/maptools/AbstractLayer.h>

// Qt Includes
#include <QStringList>

// STL includes
#include <list>
#include <vector>

// GeoDMA Includes
#include "geodma_tvplugin/config.hpp"
#include "geodma_tvplugin/featureExtractionController.hpp"

namespace gdma {
namespace tvplg {
class GDMATVPLGEXPORT SpectralAndSpatialFeaturesController :
    public gdma::tvplg::FeatureExtractionController {
 public:
    SpectralAndSpatialFeaturesController();

    ~SpectralAndSpatialFeaturesController();

    bool computeFeatures();

    void getRasterProperties(std::size_t &n_bands);

    void setInputBands(std::vector<unsigned int> bands);

    void setComputeSpectral(bool compute);

    void setComputeSpatial(bool compute);
 private:
    std::vector<unsigned int> m_inputBands;

    bool m_computeSpectral;
    bool m_computeSpatial;
};
}  // namespace tvplg
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_SPECTRALANDSPATIALFEATURESCONTROLLER_HPP_
