/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/classification/c50Parameters.hpp

  \brief This file contains the C50Parameters class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// STL Includes
#include <ctime>

// GeoDMA Includes
#include "geodmalib/classification/decision_trees/c50Parameters.hpp"


gdma::cl::C50Parameters::C50Parameters() {
    m_subset = true;
    m_rules = false;
    m_utility = 0;
    m_trials = 1;
    m_winnow = false;
    m_trainSamples = 0.66;
    m_seed = std::time(0) & 07777;
    m_noGlobalPruning = false;
    m_confidenceFactor = 0.25;
    m_minCases = 2;
    m_fuzzyThreshold = false;
    m_earlyStopping = true;
}


gdma::cl::C50Parameters::~C50Parameters() {
}

void gdma::cl::C50Parameters::reset() {
    this->m_subset = true;
    this->m_rules = false;
    this->m_utility = 0;
    this->m_trials = 1;
    this->m_winnow = false;
    this->m_trainSamples = 0;
    this->m_seed = std::time(0) & 07777;
    this->m_noGlobalPruning = false;
    this->m_confidenceFactor = 0.25;
    this->m_minCases = 2;
    this->m_fuzzyThreshold = false;
    this->m_earlyStopping = true;
}

gdma::cl::C50Parameters* gdma::cl::C50Parameters::clone() const {
    gdma::cl::C50Parameters* newObj = new gdma::cl::C50Parameters();

    newObj->m_subset = this->m_subset;
    newObj->m_rules = this->m_rules;
    newObj->m_utility = this->m_utility;
    newObj->m_trials = this->m_trials;
    newObj->m_winnow = this->m_winnow;
    newObj->m_trainSamples = this->m_trainSamples;
    newObj->m_seed = this->m_seed;
    newObj->m_noGlobalPruning = this->m_noGlobalPruning;
    newObj->m_confidenceFactor = this->m_confidenceFactor;
    newObj->m_minCases = this->m_minCases;
    newObj->m_fuzzyThreshold = this->m_fuzzyThreshold;
    newObj->m_earlyStopping = this->m_earlyStopping;

    return newObj;
}
