/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/classification/c50Parameters.cpp

  \brief This file contains the C50Parameters class implementation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_CLFC_INTERNAL_C50PARAMETERS_HPP_
#define GEODMA_LIB_CLFC_INTERNAL_C50PARAMETERS_HPP_

// TerraLib Includes
#include <terralib/common/AbstractParameters.h>

// GeoDMA Includes
#include "geodmalib/classification/config.hpp"

namespace gdma {
namespace cl {
class GDMACLEXPORT C50Parameters : te::common::AbstractParameters {
 public:
    C50Parameters();

    ~C50Parameters();

    void reset() override;

    gdma::cl::C50Parameters* clone() const override;

 public:
     // @TODO(Raian): What about case weights (weights) parameter? Should it be here? How it will
     // be passed to the algorithm?
    bool m_subset;  //!< A logical: should the model evaluate groups of discrete predictors for
                    // splits? Note : the C5.0 command line version defaults this parameter to FALSE,
                    // meaning no attempted gropings will be evaluated during the tree growing stage.
    bool m_rules;  //!< A logical: should the tree be decomposed into a rule-based model?
    int m_utility;  //!< An integer between 2 and 1000. If TRUE, the model orders the rules by their
                   // affect on the error rate and groups the rules into the specified number of
                   // bands.This modifies the output so that the effect on the error rate can be
                   // seen for the groups of rules within a band.If this options is selected and
                   // rules = FALSE, a warning is issued and rules is changed to TRUE.
    int m_trials;  //!< An integer specifying the number of boosting iterations. A value of one
                   // indicates that a single model is used.
    bool m_winnow;  //!< A logical: should predictor winnowing (i.e feature selection) be used?
    double m_trainSamples;  //!< A value between (0, .999) that specifies the random proportion of
                            // the data should be used to train the model. By default, all the
                            // samples are used for model training. Samples not used for training
                            // are used to evaluate the accuracy of the model in the printed output.
    int m_seed;  //!< An integer for the random number seed within the C code.
    bool m_noGlobalPruning;  //!< A logical to toggle whether the final, global pruning step to
                              // simplify the tree.
    double m_confidenceFactor;  //!< A number in (0, 1) for the confidence factor.
    int m_minCases;  //!< An integer for the smallest number of samples that must be put in at
                     // least two of the splits.
    bool m_fuzzyThreshold;  //!< A logical toggle to evaluate possible advanced splits of the
                            // data. See Quinlan (1993) for details and examples.
    bool m_earlyStopping;  //!< A logical to toggle whether the internal method for stopping
                           // boosting should be used.
};
}  // namespace cl
}  // namespace gdma

#endif  // GEODMA_LIB_CLFC_INTERNAL_C50PARAMETERS_HPP_
