/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/commandLineMsgObserver.cpp

  \brief  A concrete observer that display Messages in the command line.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// STL includes
#include <iostream>
#include <string>

// GeoDMA includes
#include "geodmalib/common/commandLineMsgObserver.hpp"


gdma::common::CommandLineMsgObserver::CommandLineMsgObserver() {
}


gdma::common::CommandLineMsgObserver::~CommandLineMsgObserver() {
}

void gdma::common::CommandLineMsgObserver::displayInformationMsg(std::string message) {
    std::cout << message << std::endl;
}

void gdma::common::CommandLineMsgObserver::displayWarningMsg(std::string message) {
    std::cout << "WARNING: " << message << std::endl;
}

void gdma::common::CommandLineMsgObserver::displayErrorMsg(std::string message) {
    std::cout << "ERROR: " << message << std::endl;
}

void gdma::common::CommandLineMsgObserver::displayDebugMsg(std::string message) {
    // @TODO(Raian): Verify if I can get here the informations about where it was called
    std::cout << "<DEBUG>: " << message << std::endl;
}

void gdma::common::CommandLineMsgObserver::displayTraceMsg(std::string message) {
    // @TODO(Raian): Verify if I can get here the informations about where it was called
    std::cout << "<TRACE>: " << message << std::endl;
}

void gdma::common::CommandLineMsgObserver::displayFatalMsg(std::string message) {
    std::cout << "FATAL: " << message << std::endl;
}
