/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/commandLineMsgObserver.hpp

  \brief  A concrete observer that display Messages in the command line.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/common/abstractMessageObserver.hpp"

#ifndef GEODMA_LIB_COMMON_COMMANDLINEMSGOBSERVER_HPP_
#define GEODMA_LIB_COMMON_COMMANDLINEMSGOBSERVER_HPP_

namespace gdma {
namespace common {
/*!
  \class CommandLineMsgObserver

  \brief A concrete observer that display Messages in the command line.

  This class implements the interface \ref AbstractMessageObserver and is used to display messages
  received from \ref MessageMediator in the command line.

  \ingroup common

  \sa MessageMediator, AbstractMessageObserver, LogMessageObserver
*/
class GDMACOMMONEXPORT CommandLineMsgObserver : public AbstractMessageObserver {
 public:
    /*! \brief Default constructor. */
    CommandLineMsgObserver();

    /*! \brief Default destructor. */
    ~CommandLineMsgObserver();

    /*!
      \brief Display an information message.
      \param[in] message The information message to be displayed.
    */
    void displayInformationMsg(std::string msg) override;

    /*!
      \brief Display a warning message.
      \param[in] message The warning message to be displayed.
    */
    void displayWarningMsg(std::string msg) override;

    /*!
      \brief Display an error message.
      \param[in] message The error message to be displayed.
    */
    void displayErrorMsg(std::string msg) override;

    /*!
      \brief Display a debug message.
      \param[in] message The debug message to be displayed.
    */
    void displayDebugMsg(std::string msg) override;

    /*!
      \brief Display a trace message.
      \param[in] message The trace message to be displayed.
    */
    void displayTraceMsg(std::string msg) override;

    /*!
      \brief Display a fatal message.
      \param[in] message The fatal message to be displayed.
    */
    void displayFatalMsg(std::string msg) override;
};
}  // namespace common
}  // namespace gdma

#endif  // GEODMA_LIB_COMMON_COMMANDLINEMSGOBSERVER_HPP_
