/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/commandLineStatusBar.hpp

  \brief Command line status bar.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_COMMON_COMMANDLINESTATUSBAR_HPP_
#define GEODMA_LIB_COMMON_COMMANDLINESTATUSBAR_HPP_

// Boost Includes
#include <boost/chrono.hpp>

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/common/config.hpp"

namespace gdma {
namespace common {
/*!
  \struct CommandLineStatusBar

  \brief Command line status bar.
*/
class GDMACOMMONEXPORT CommandLineProgBar {
 public:
    /*! \brief Default Constructor. */
    explicit CommandLineProgBar(const std::string& label = "", double total_steps = 0,
        int barWidth = 80);

    /*! 
      \brief Copy Constructor.
      \param rhs The right-hand-side copy used to copy from.
    */
    CommandLineProgBar(const CommandLineProgBar &rhs);

    /*!
      \brief Destructor
    */
    ~CommandLineProgBar();

    void pulse();

 private:
    void setBar();

 private:
    double m_progress;
    int m_barWidth;
    int m_posBar;
    boost::chrono::high_resolution_clock::time_point m_startTime;
    boost::chrono::duration<int> m_currentTime;
    double m_totalSteps;
    std::string m_bar;
    std::string m_label;
};
}  // end namespace common
}  // end namespace gdma

#endif  // GEODMA_LIB_COMMON_COMMANDLINESTATUSBAR_HPP_
