/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/commandLineProgViewer.hpp

  \brief Command line progress bar viewer, based on TerraLib AbstractProgressViewer.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_COMMON_COMMANDLINEPROGVIEWER_HPP_
#define GEODMA_LIB_COMMON_COMMANDLINEPROGVIEWER_HPP_

// TerraLib Includes
#include <terralib/common/progress/AbstractProgressViewer.h>
#include <terralib/common/progress/TaskProgress.h>

// STL includes
#include <chrono>
#include <map>
#include <string>

// GeoDMA includes
#include "geodmalib/common/config.hpp"

namespace gdma {
namespace common {
/*!
  \struct CommandLineStatusBar

  \brief Command line progress bar viewer.
*/
class GDMACOMMONEXPORT CommandLineProgViewer : public te::common::AbstractProgressViewer {
 public:
    /*! \brief Default constructor */
    CommandLineProgViewer();

    explicit CommandLineProgViewer(int barWidth);

    /*! \brief Default virtual destructor */
    ~CommandLineProgViewer();

    void addTask(te::common::TaskProgress* tsk, int id);

    void removeTask(int taskId);

    void cancelTask(int taskId);

    void setTotalValues(int taskId);

    void updateValue(int taskId);

    void updateMessage(int taskId);

 private:
    void setBar();

 private:
    int m_totalSteps;                  //!< Attribute used to define the total steps of all tasks.
    int m_currentStep;                 //!< Attribute used to define the current steps of all task.
    // int m_propStep;                 //!< Attribute used to define the proportional step (0-100).

    double m_progress;
    int m_positionBar;

    int m_barWidth;
    int m_totalWidth;
    std::chrono::high_resolution_clock::time_point m_startTime;
    std::chrono::duration<int> m_currentTime;
    std::string m_barStr;
    std::string m_message;             //!< Attribute used to define the progress message.
    std::map<int, te::common::TaskProgress*> m_tasks;   //!< Task container.
};
}  // namespace common
}  // namespace gdma

#endif  // GEODMA_LIB_COMMON_COMMANDLINEPROGVIEWER_HPP_
