/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/config.hpp

  \brief Configuration flags for the GeoDMA Data Manager Runtime module.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/


#ifndef GEODMA_LIB_COMMON_INTERNAL_CONFIG_HPP_
#define GEODMA_LIB_COMMON_INTERNAL_CONFIG_HPP_

#define GDMA_COMMON_MODULE_NAME "gdma.common"

/** @name DLL/LIB Module
*  Flags for building GeoDMA as a DLL or as a Static Library
*/
//@{

/*!
\def GDMACOMMONEXPORT

\brief You can use this macro in order to export/import classes and functions from this module.

\note If you want to compile TerraLib as DLL in Windows, remember to insert GDMACOMMONDLL into the
project's list of defines.

\note If you want to compile GeoDMA Data Manager Library as an Static Library under Windows,
remember to insert the GDMACOMMONSTATIC flag into the project list of defines.
*/
#ifdef WIN32

#ifdef GDMACOMMONSTATIC
#define GDMACOMMONEXPORT                          // Don't need to export/import... it is a static
                                                  // library
#elif GDMACOMMONDLL
#define GDMACOMMONEXPORT  __declspec(dllexport)   // export DLL information
#else
#define GDMACOMMONEXPORT  __declspec(dllimport)   // import DLL information
#endif
#else
#define GDMACOMMONEXPORT
#endif

//@}

#endif  // GEODMA_LIB_COMMON_INTERNAL_CONFIG_HPP_

