/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/fileSystem.hpp

  \brief This file contains some File system related functions.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_COMMON_FILESYSTEM_HPP_
#define GEODMA_LIB_COMMON_FILESYSTEM_HPP_

// Boost includes
#include <boost/filesystem.hpp>

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/common/config.hpp"

namespace gdma {
namespace common {
/*!
  \brief Find a file in GeoDMA path.
  \param[in] An string containing the relative path to the file.
  \return The full path to the given file.
*/
GDMACOMMONEXPORT std::string FindInGeoDMAPath(std::string path);

/*!
  \brief Set an environment variable in the system. This variable is only valid during the execution
         of the program. 
  \param[in] A char* containing the name of the environment variable.
  \param[in] A char* containing the value of the environment variable.
*/
GDMACOMMONEXPORT void SetEnvVariable(char* varName, char* value);

/*!
  \brief Loads the contents of a text file. 
  \param[in] A string containing the path to the file being loaded.
  \param[out] A string containing the contents of the file.
  \return Returns true if the file was successfully read, false otherwise.
*/
GDMACOMMONEXPORT bool loadTextFileToString(const std::string pathToFile, std::string& fileContents);

/*!
  \brief Saves the contents of a string in a text file. 
  \param[in] A boost::filesystem::path containing the path to the file being saved.
  \param[in] A string containing the contents to be saved in the file.
  \return Returns true if the file was successfully saved, false otherwise.
*/
GDMACOMMONEXPORT bool saveStringToTextFile(const boost::filesystem::path pathToFile,
    const std::string& fileContents);
}  // namespace common
}  // namespace gdma
#endif  // GEODMA_LIB_COMMON_FILESYSTEM_HPP_
