/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/logLineMsgObserver.cpp

  \brief  A concrete observer that save Messages in a log file.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib Includes
#include <terralib/core/logger/Logger.h>

// STL includes
#include <string>
#include <sstream>

// GeoDMA Includes
#include "geodmalib/common/logMessageObserver.hpp"


gdma::common::LogMessageObserver::LogMessageObserver(std::string pathToLog) {
    m_logPath = pathToLog;
    m_logFormat = "[%TimeStamp%] <%Severity%>: %Message%";
    m_logName = "gdmaLog";
    te::core::Logger::instance().addLogger(m_logName, pathToLog, m_logFormat);
}

gdma::common::LogMessageObserver::LogMessageObserver(std::string logName, std::string pathToLog,
    std::string format) {
    m_logName = logName;
    te::core::Logger::instance().addLogger(m_logName, pathToLog, format);
}

gdma::common::LogMessageObserver::LogMessageObserver(std::string logName, std::string pathToLog,
    bool includeTimeStamp, bool includeSeverity) {
    m_logPath = logName;

    std::stringstream format;
    if (includeTimeStamp)
        format << "[%TimeStamp%] ";

    if (includeSeverity)
        format << "<%Severity%>";

    format << ": %Message%";

    m_logFormat = format.str();

    m_logName = "gdmaLog";
    te::core::Logger::instance().addLogger(m_logName, pathToLog, m_logFormat);
}

gdma::common::LogMessageObserver::~LogMessageObserver() {
}

void gdma::common::LogMessageObserver::displayInformationMsg(std::string msg) {
    te::core::Logger::instance().log(msg, m_logName, te::core::Logger::severity_level::info);
}

void gdma::common::LogMessageObserver::displayWarningMsg(std::string msg) {
    te::core::Logger::instance().log(msg, m_logName, te::core::Logger::severity_level::warning);
}

void gdma::common::LogMessageObserver::displayErrorMsg(std::string msg) {
    te::core::Logger::instance().log(msg, m_logName, te::core::Logger::severity_level::error);
}

void gdma::common::LogMessageObserver::displayDebugMsg(std::string msg) {
    te::core::Logger::instance().log(msg, m_logName, te::core::Logger::severity_level::debug);
}

void gdma::common::LogMessageObserver::displayTraceMsg(std::string msg) {
    te::core::Logger::instance().log(msg, m_logName, te::core::Logger::severity_level::trace);
}

void gdma::common::LogMessageObserver::displayFatalMsg(std::string msg) {
    te::core::Logger::instance().log(msg, m_logName, te::core::Logger::severity_level::fatal);
}
