/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/featureextraction/spatialFeatures.hpp

  \brief Functionalities to compute segmentation-based spatial features for regions based on 
  geometries.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_COMMON_OBSERVERPROGRESSBAR_HPP_
#define GEODMA_LIB_COMMON_OBSERVERPROGRESSBAR_HPP_

#include "geodmalib/common/config.hpp"

namespace gdma {
namespace common {
template <typename ProgBar>
class ObserverProgressBar {
 public:
    ObserverProgressBar();

    explicit ObserverProgressBar(ProgBar &progBar);

    // ~ObserverProgressBar();

    inline void notifyProgress();
 private:
    ProgBar m_progBar;
};
}  // namespace common
}  // namespace gdma

template<typename ProgBar>
gdma::common::ObserverProgressBar<ProgBar>::ObserverProgressBar() {}

template<typename ProgBar>
gdma::common::ObserverProgressBar<ProgBar>::ObserverProgressBar(ProgBar &progBar) {
    m_progBar = progBar;
}

// template <typename ProgBar> gdma::common::ObserverProgressBar<ProgBar>::~ObserverProgressBar();

template <typename ProgBar> void gdma::common::ObserverProgressBar<ProgBar>::notifyProgress() {
    m_progBar.pulse();
}

#endif  // GEODMA_LIB_COMMON_OBSERVERPROGRESSBAR_HPP_
