/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/dataManager/utils.cpp

  \brief Implements some useful functions to manage data.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib Includes
#include <terralib/dataaccess/dataset/DataSet.h>

// STL Includes
#include <time.h>
#include <algorithm>
#include <set>
#include <vector>

// GeoDMA Includes
#include "geodmalib/datamanager/utils.hpp"


void gdma::dm::generateRandomSequence(te::da::DataSetPtr dataset, int numberOfPositions,
    std::vector<unsigned int>& vec_positions, double randomSeed) {
    if (randomSeed == 0)
        randomSeed = time(NULL);

    std::srand(randomSeed);

    std::set<std::size_t> positions;

    while (positions.size() < numberOfPositions) {
        positions.insert(std::rand() % dataset->size());
    }

    vec_positions.clear();
    std::copy(positions.begin(), positions.end(), std::back_inserter(vec_positions));

    std::sort(vec_positions.begin(), vec_positions.end());
}
