/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/featureextraction/multiGeometryAlgorithms.hpp

  \brief Util functionalities to deal with geometry collections manipulation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_FEATURESEXTRACTION_MULTIGEOMETRYALGORITHMS_HPP_
#define GEODMA_LIB_FEATURESEXTRACTION_MULTIGEOMETRYALGORITHMS_HPP_

// Terralib includes
#include <terralib/geometry.h>

// STL includes
#include <vector>

// GeoDMA includes
#include "geodmalib/featureextraction/config.hpp"

namespace gdma {
namespace fte {
/*!
  \brief Method to break a MultiGeometry into a vector of geometries, filtering that of of the type
         Polygon, ignoring another different geometry types.
  \param[in] geometry The MultiGeometry to be partitioned.
  \param[out] geometryVector The generated vector of geometries.
*/
GDMAFTEEXPORT void Multi2SilgleFilterPolygons(te::gm::Geometry* geometry,
    std::vector<te::gm::Geometry*> &geometryVector);

/*!
  \brief Method to break a MultiGeometry into a vector of geometries, filtering that of the type
         LineString, ignoring another different geometry types.
  \param[in] geometry The MultiGeometry to be partitioned.
  \param[out] geometryVector The generated vector of geometries.
*/
GDMAFTEEXPORT void Multi2SilgleFilterLineStrings(te::gm::Geometry* geometry,
    std::vector<te::gm::Geometry*> &geometryVector);

/*!
  \brief Method to break a MultiGeometry into a vector of geometries of the type Polygon,
        throwing an exception if another type is found.
  \param[in] geometry The MultiGeometry to be partitioned.
  \param[out] geometryVector The generated vector of geometries.
*/
GDMAFTEEXPORT void Multi2SilgleFilterPolygonsRestrict(te::gm::Geometry* geometry,
    std::vector<te::gm::Geometry*> &geometryVector);

/*!
  \brief Method to break a MultiGeometry into a vector of geometries of the type LineString,
        throwing an exception if another type is found.
  \param[in] geometry The MultiGeometry to be partitioned.
  \param[out] geometryVector The generated vector of geometries.
*/
GDMAFTEEXPORT void Multi2SilgleFilterLineStringRestrict(te::gm::Geometry* geometry,
    std::vector<te::gm::Geometry*> &geometryVector);

}  // namespace fte
}  // namespace gdma

#endif  // GEODMA_LIB_FEATURESEXTRACTION_MULTIGEOMETRYALGORITHMS_HPP_
