/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/c50ClassificationController.hpp

  \brief This file contains the SampleSelectionWidget class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_GUICMP_C50CLASSIFICATIONCONTROLLER_HPP_
#define GEODMA_LIB_GUICMP_C50CLASSIFICATIONCONTROLLER_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>

// Boost Filesystem
#include <boost/filesystem.hpp>

// STL Includes
#include <list>
#include <map>
#include <string>
#include <vector>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"
#include "geodmalib/classification/decision_trees/c50DecisionTree.hpp"
#include "geodmalib/classification/decision_trees/c50Parameters.hpp"

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT C50ClassificationController {
 public:
     /* \brief Default Constructor. */
     C50ClassificationController();

     /* \brief Default Destructor. */
     ~C50ClassificationController();

     void setCurrentLayer(te::map::AbstractLayerPtr layer);

     te::map::AbstractLayerPtr getCurrentLayer();

     void setLayerList(std::list<te::map::AbstractLayerPtr> layerList);

     std::list<te::map::AbstractLayerPtr> getLayerList();

     void setLabelsColumn(std::string name);

     std::string getLabelsColumn();

     void setAvailableFeatures();

     std::vector<std::string> getAvailableFeatures();

     void setTrials(int trials);

     int getTrials();

     void setGlobalPruning(bool globalPruning);

     bool getGlobalPruning();

     void setMinCases(int minCases);

     int getMinCases();

     void setTrainingSamples(double trainSamples);

     double getTrainingSamples();

     void setWinnow(bool winnow);

     bool getWinnow();

     void setRules(bool winnow);

     bool getRules();

     void setFuzzyThresholds(bool fuzzy);

     bool getFuzzyThresholds();

     void setEarlyStopping(bool earlyStopping);

     bool getEarlyStopping();

     void setSubset(bool subset);

     bool getSubset();

     void setConfidenceFactor(double confFactor);

     double getConfidenceFactor();

     void setFeaturesToUse(std::vector<std::string> featuresToUse);

     void trainTree();

     std::string getOutputText();

     std::string getTreeText();

     std::string getRulesText();

     void setOutputFilesPath(boost::filesystem::path path);

     boost::filesystem::path getOutputFilesPath();

     void saveOutputFiles();

     bool loadExternalFiles(std::string pathToFiles);

     void predict();

     void setOutputColumnName(std::string columnName);

     std::string getOutputColumnName();

     bool savePredictionOutput(const std::string pathShp, const std::string layerName, const std::string pathCSV);

     bool newLayerCreated();

     std::string getCurrentDataSourcePath();

     void setNoDataValue(int value);

     int getNoDataValue();

 protected:
     gdma::cl::C50DecisionTree m_c50DecisionTree;
     te::map::AbstractLayerPtr m_currentLayer;
     std::list<te::map::AbstractLayerPtr> m_layerList;
     std::vector<std::string> m_availableFeatures;
     boost::filesystem::path m_outputFilesPath;
     bool m_newLayerCreated;
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_LIB_GUICMP_C50CLASSIFICATIONCONTROLLER_HPP_
