/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/guicomponents/c50ClassificationWidget.hpp

  \brief This file contains the SampleSelectionWidget class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_GUICMP_C50CLASSIFICATIONWIDGET_HPP_
#define GEODMA_LIB_GUICMP_C50CLASSIFICATIONWIDGET_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/widgets/utils/DoubleListWidget.h>

// Qt Includes
#include <QString>
#include <QTreeWidget>
#include <QWidget>

// STL Includes
#include <list>
// #include <map>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ClassificationController.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ParametersDialog.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ResultsDialog.hpp"
#include "geodmalib/guicomponents/outputDataWidget.hpp"

namespace Ui { class C50ClassificationWidgetForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT C50ClassificationWidget : public QWidget {
    Q_OBJECT

 public:
    /*!
      \brief Default Constructor
    */
    explicit C50ClassificationWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);

    /*!
      \brief Default Destructor
    */
    ~C50ClassificationWidget();

    /*!
      \brief Used to get access to the Widget Components
    */
    Ui::C50ClassificationWidgetForm* getForm() const;

    void setLayers(std::list<te::map::AbstractLayerPtr> layers);

    void setCurrentLayer(te::map::AbstractLayerPtr layer);

    bool run();

    gdma::guicmp::C50ClassificationController* getController();

    void goToClassificationTab();

    void setInputTreeFileText();

 signals:
    void trainingRan();
    void predictionRan();

 public slots: //NOLINT
    void onInputLayerComboBoxSelected(int index);
    void onLabelColumnComboBoxSelected(int index);
    void onTrialsSpinBoxChanged(int val);
    void onGlobalPruningCheckBoxStateChanged(int state);
    void onMinCasesSpinBoxChanged(int val);
    void onTrainSampleSpinBoxChanged(double val);
    void onAdvancedParametersToolButtonClicked();
    void onTabBarClicked(int tabIdx);
    void onInputTreeFileToolButtonClicked();
    void onNoDataLineEditChanged(int val);

 private:
     std::unique_ptr<Ui::C50ClassificationWidgetForm> m_ui;  //!< User interface
     std::unique_ptr<te::qt::widgets::DoubleListWidget> m_featuresWidget;
     std::unique_ptr<gdma::guicmp::C50ParametersDialog> m_advancedParamDlg;
     std::unique_ptr<gdma::guicmp::OutputDataWidget> m_outputWidget;

    std::list<te::map::AbstractLayerPtr> m_vectorLayers;  //!< All vector layers of the application

    gdma::guicmp::C50ClassificationController m_controller;
    QString m_noColumnName;
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_LIB_GUICMP_C50CLASSIFICATIONWIDGET_HPP_
