/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/c50ClassificationDialog.cpp

  \brief This file contains the C50ClassificationDialog implementation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// Qt Includes
#include <QDialog>
#include <QGridLayout>
#include <QMessageBox>

// STL Includes
#include <list>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/decision_trees/c50ParametersDialog.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ParametersWidget.hpp"
#include "geodmalib/guicomponents/dialogMessageObserver.hpp"
#include "ui_GeoDMADialogForm.h"


gdma::guicmp::C50ParametersDialog::C50ParametersDialog(QWidget* parent, Qt::WindowFlags f) :
    QDialog(parent, f),
    m_ui(new Ui::GeoDMADialogForm) {
    m_ui->setupUi(this);

    m_dialogTitle = "GeoDMA C5.0 Parameters";

    m_ui->m_panelFrame->hide();
    QSize dlgSize(339, 202);
    this->resize(dlgSize);

    QGridLayout* layout = new QGridLayout(m_ui->m_widget);
    m_c50ParametersWidget.reset(new gdma::guicmp::C50ParametersWidget(m_ui->m_widget));
    layout->addWidget(m_c50ParametersWidget.get(), 0, 0);
    layout->setContentsMargins(0, 0, 0, 0);

    // add icons
    this->setWindowIcon(QIcon::fromTheme("icon_geodma"));

    // Hide Frame
    m_ui->m_panelFrame->hide();
    this->setWindowTitle(tr("C5.0 Advanced Parameters"));

    m_ui->m_runPushButton->setText(tr("Ok"));
    m_ui->m_closePushButton->setText(tr("Cancel"));

    connect(m_ui->m_runPushButton, SIGNAL(released()), this, SLOT(onOkPushButtonClicked()));
    connect(m_ui->m_runPushButton, SIGNAL(released()), this, SLOT(close()));

    connect(m_ui->m_closePushButton, SIGNAL(released()), this, SLOT(onCancelPushButtonClicked()));
    connect(m_ui->m_closePushButton, SIGNAL(released()), this, SLOT(close()));

    m_ui->m_helpPushButton->setNameSpace("dpi.inpe.br.geodma");
    m_ui->m_helpPushButton->setPageReference(
        "geodma/decision_trees/geodma_c50_decision_trees.html#advanced-parameters");
}


gdma::guicmp::C50ParametersDialog::~C50ParametersDialog() {
}

void gdma::guicmp::C50ParametersDialog::initialize(
    gdma::guicmp::C50ClassificationController &controller) {
    m_controller = &controller;
}

// ------------- Slots (Public)
void gdma::guicmp::C50ParametersDialog::onOkPushButtonClicked() {
    m_controller->setWinnow(m_c50ParametersWidget->getWinnow());
    m_controller->setRules(m_c50ParametersWidget->getRules());
    m_controller->setFuzzyThresholds(m_c50ParametersWidget->getFuzzyThresholds());
    m_controller->setEarlyStopping(m_c50ParametersWidget->getEarlyStopping());
    m_controller->setSubset(m_c50ParametersWidget->getSubset());
    m_controller->setConfidenceFactor(m_c50ParametersWidget->getConfidenceFactor());
}

void gdma::guicmp::C50ParametersDialog::onCancelPushButtonClicked() {
}

// ------------- Protected Members

void gdma::guicmp::C50ParametersDialog::closeEvent(QCloseEvent*) {
    emit parametersSetted();
}
