/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/c50ResultsDialog.hpp

  \brief This file contains the C50ResultsDialog class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_C50PARAMETERSIALOG_HPP_
#define GEODMA_TVPLUGIN_C50PARAMETERSIALOG_HPP_

// Qt Includes
#include <QDialog>

// STL Includes
#include <list>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/decision_trees/c50ClassificationController.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ParametersWidget.hpp"
#include "geodma_tvplugin/config.hpp"

namespace Ui { class GeoDMADialogForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT C50ParametersDialog : public QDialog {
    Q_OBJECT

 public:
    explicit C50ParametersDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~C50ParametersDialog();

    void initialize(gdma::guicmp::C50ClassificationController &controller);

 public slots: //NOLINT
    void onOkPushButtonClicked();
    void onCancelPushButtonClicked();

 protected:
    void closeEvent(QCloseEvent* e);

 signals:
    void parametersSetted();

 private:
     std::unique_ptr<Ui::GeoDMADialogForm> m_ui;
     std::unique_ptr<gdma::guicmp::C50ParametersWidget> m_c50ParametersWidget;

     gdma::guicmp::C50ClassificationController* m_controller;

     std::string m_dialogTitle;
     int m_msgObsId;
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_C50PARAMETERSIALOG_HPP_
