/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/guicomponents/c50ResultsWidget.cpp

  \brief This file contains the C50ResultsWidget class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

/// STL Includes
// #include <map>
// #include <memory>
// #include <string>

// QT Includes
#include <QWidget>

// GeoDMA Includes
#include "geodmalib/common/messageMediator.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ParametersWidget.hpp"
#include "ui_C50ParametersWidgetForm.h"


gdma::guicmp::C50ParametersWidget::C50ParametersWidget(QWidget* parent, Qt::WindowFlags f) :
    QWidget(parent, f),
    m_ui(new Ui::C50ParametersWidgetForm) {
    m_ui->setupUi(this);
}


gdma::guicmp::C50ParametersWidget::~C50ParametersWidget() {
}

bool gdma::guicmp::C50ParametersWidget::getWinnow() {
    return m_ui->m_winnowCheckBox->isChecked();
}

bool gdma::guicmp::C50ParametersWidget::getRules() {
    return m_ui->m_rulesCheckBox->isChecked();
}

bool gdma::guicmp::C50ParametersWidget::getFuzzyThresholds() {
    return m_ui->m_fuzzyThresCheckBox->isChecked();
}

bool gdma::guicmp::C50ParametersWidget::getEarlyStopping() {
    return m_ui->m_earlyStopCheckBox->isChecked();
}

bool gdma::guicmp::C50ParametersWidget::getSubset() {
    return m_ui->m_subsetCheckBox->isChecked();
}

double gdma::guicmp::C50ParametersWidget::getConfidenceFactor() {
    return m_ui->m_confFactorSpinBox->value();
}
