/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/guicomponents/c50ResultsWidget.hpp

  \brief This file contains the C50ResultsWidget class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_GUICMP_C50PARAMETERSWIDGET_HPP_
#define GEODMA_LIB_GUICMP_C50PARAMETERSWIDGET_HPP_

// QT Includes
#include <QWidget>

// STL Includes
#include <map>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ClassificationController.hpp"

namespace Ui { class C50ParametersWidgetForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT C50ParametersWidget : public QWidget {
    Q_OBJECT

 public:
    explicit C50ParametersWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~C50ParametersWidget();

    bool getWinnow();

    bool getRules();

    bool getFuzzyThresholds();

    bool getEarlyStopping();

    bool getSubset();

    double getConfidenceFactor();

 protected:
     std::unique_ptr<Ui::C50ParametersWidgetForm> m_ui;  //!< User interface
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_LIB_GUICMP_C50PARAMETERSWIDGET_HPP_
