/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/geodma_tvplugin/c50ClassificationDialog.cpp

  \brief This file contains the C50ClassificationDialog implementation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib Includes
// #include <terralib/common/progress/ProgressManager.h>
// #include <terralib/qt/widgets/progress/ProgressViewerDialog.h>

// Qt Includes
#include <QDialog>
#include <QGridLayout>
#include <QMessageBox>

// STL Includes
#include <list>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/common/messageMediator.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ResultsWidget.hpp"
#include "geodmalib/guicomponents/dialogMessageObserver.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ResultsDialog.hpp"
#include "ui_GeoDMADialogForm.h"


gdma::guicmp::C50ResultsDialog::C50ResultsDialog(QWidget* parent, Qt::WindowFlags f) :
    QDialog(parent, f),
    m_ui(new Ui::GeoDMADialogForm) {
    m_ui->setupUi(this);

    m_dialogTitle = "GeoDMA C5.0 Results";
    this->setWindowTitle(m_dialogTitle.c_str());

    QGridLayout* layout = new QGridLayout(m_ui->m_widget);
    m_c50ResultsWidget.reset(new gdma::guicmp::C50ResultsWidget(m_ui->m_widget));
    layout->addWidget(m_c50ResultsWidget.get(), 0, 0);
    layout->setContentsMargins(0, 0, 0, 0);

    QSize dlgSize(700, 420);
    this->resize(dlgSize);

    // add icons
    this->setWindowIcon(QIcon::fromTheme("icon_geodma"));
    m_ui->m_gdmaImgLabel->setPixmap(QIcon::fromTheme("icon_geodma_name").pixmap(112, 65));
    m_ui->m_panelImgLabel->setPixmap(QIcon::fromTheme("decisionTree_Classification")
        .pixmap(112, 48));

    m_ui->m_panelTextLabel->setText("C5.0 Decision Trees Results");
    m_ui->m_closePushButton->setText(tr("Close"));
    m_ui->m_runPushButton->hide();

    connect(m_ui->m_closePushButton, SIGNAL(released()), this, SLOT(onClosePushButtonClicked()));
    connect(m_ui->m_closePushButton, SIGNAL(released()), this, SLOT(close()));

    m_ui->m_helpPushButton->setNameSpace("dpi.inpe.br.geodma");
    m_ui->m_helpPushButton->setPageReference(
        "geodma/decision_trees/geodma_c50_decision_trees.html#results-window");
}


gdma::guicmp::C50ResultsDialog::~C50ResultsDialog() {
}

void gdma::guicmp::C50ResultsDialog::initialize(
    gdma::guicmp::C50ClassificationController *controller) {
    m_c50ResultsWidget->initialize(controller);
}

void gdma::guicmp::C50ResultsDialog::askToSave() {
    QMessageBox::StandardButton reply;
    reply = QMessageBox::question(this, "Unsaved Results",
        "Do you want to save the results?",
        QMessageBox::Yes | QMessageBox::No);

    if (reply == QMessageBox::No)
        return;
    else
        m_c50ResultsWidget->getOutputFileNamesFromUser();
}

void gdma::guicmp::C50ResultsDialog::onClosePushButtonClicked() {
    if (!m_c50ResultsWidget->isToSave())
        askToSave();

    m_c50ResultsWidget->saveOutputFiles();

    emit resultsDialogClosed();
}
