/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/c50ResultsDialog.hpp

  \brief This file contains the C50ResultsDialog class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_TVPLUGIN_C50RESULTSIALOG_HPP_
#define GEODMA_TVPLUGIN_C50RESULTSIALOG_HPP_

// Qt Includes
#include <QDialog>

// STL Includes
#include <list>
#include <memory>
#include <string>

// GeoDMA Includes
#include "c50ResultsWidget.hpp"
#include "geodma_tvplugin/config.hpp"

namespace Ui { class GeoDMADialogForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT C50ResultsDialog : public QDialog {
    Q_OBJECT

 public:
    explicit C50ResultsDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~C50ResultsDialog();

    void initialize(gdma::guicmp::C50ClassificationController *controller);

    void askToSave();

 public slots: //NOLINT
    void onClosePushButtonClicked();

 signals:
    void resultsDialogClosed();

 private:
     std::unique_ptr<Ui::GeoDMADialogForm> m_ui;
     std::unique_ptr<gdma::guicmp::C50ResultsWidget> m_c50ResultsWidget;

     std::string m_dialogTitle;
     int m_msgObsId;
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_C50RESULTSIALOG_HPP_
