/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/guicomponents/c50ResultsWidget.cpp

  \brief This file contains the C50ResultsWidget class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib Includes
#include <terralib/core/translator/Translator.h>

// Boost Includes
#include <boost/filesystem.hpp>

// QT Includes
#include <QFileDialog>
#include <QWidget>

/// STL Includes
#include <map>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/common/messageMediator.hpp"
#include "geodmalib/guicomponents/decision_trees/c50ResultsWidget.hpp"
#include "ui_C50ResultsWidgetForm.h"


gdma::guicmp::C50ResultsWidget::C50ResultsWidget(QWidget* parent, Qt::WindowFlags f) :
    QWidget(parent, f),
    m_ui(new Ui::C50ResultsWidgetForm) {
    m_ui->setupUi(this);

    QFont font("Courrier");
    font.setStyleHint(QFont::Monospace);
    m_ui->m_outputTextBrowser->setFont(font);

    connect(m_ui->m_outputTextToolButton, SIGNAL(toggled(bool)), this,
        SLOT(onOutputTextButtonChecked(bool)));
    connect(m_ui->m_showTreeToolButton, SIGNAL(toggled(bool)), this,
        SLOT(onShowTreeToolButtonChecked(bool)));
    connect(m_ui->m_showRulesToolButton, SIGNAL(toggled(bool)), this,
        SLOT(onShowRulesToolButtonChecked(bool)));
    connect(m_ui->m_outputFilesToolButton, SIGNAL(clicked()), this,
        SLOT(onOutputFilesToolButtonClicked()));
}


gdma::guicmp::C50ResultsWidget::~C50ResultsWidget() {
}

void gdma::guicmp::C50ResultsWidget::initialize(
    gdma::guicmp::C50ClassificationController* controller) {
    m_controller = controller;

    m_ui->m_outputTextBrowser->setText(m_controller->getOutputText().c_str());

    if (m_controller->getRulesText().compare("") == 0)
        m_ui->m_showRulesToolButton->setEnabled(false);
    else
        m_ui->m_showRulesToolButton->setEnabled(true);

    if (m_controller->getTreeText().compare("") == 0)
        m_ui->m_showTreeToolButton->setEnabled(false);
    else
        m_ui->m_showTreeToolButton->setEnabled(true);
}

void gdma::guicmp::C50ResultsWidget::saveOutputFiles() {
    if (!m_controller->getOutputFilesPath().empty())
        m_controller->saveOutputFiles();
}

bool gdma::guicmp::C50ResultsWidget::isToSave() {
    return !m_ui->m_outFilesLineEdit->text().isEmpty();
}

void gdma::guicmp::C50ResultsWidget::onOutputTextButtonChecked(bool checked) {
    m_ui->m_outputTextBrowser->clear();
    if (checked)
        m_ui->m_outputTextBrowser->setText(m_controller->getOutputText().c_str());
}

void gdma::guicmp::C50ResultsWidget::onShowTreeToolButtonChecked(bool checked) {
    m_ui->m_outputTextBrowser->clear();
    if (checked)
        m_ui->m_outputTextBrowser->setText(m_controller->getTreeText().c_str());
}

void gdma::guicmp::C50ResultsWidget::onShowRulesToolButtonChecked(bool checked) {
    m_ui->m_outputTextBrowser->clear();
    if (checked)
        m_ui->m_outputTextBrowser->setText(m_controller->getRulesText().c_str());
}

void gdma::guicmp::C50ResultsWidget::onOutputFilesToolButtonClicked() {
    m_ui->m_outFilesLineEdit->clear();

    getOutputFileNamesFromUser();

    m_ui->m_outFilesLineEdit->setText(m_controller->getOutputFilesPath().string().c_str());
}

void gdma::guicmp::C50ResultsWidget::getOutputFileNamesFromUser() {
    QFileInfo fileInfo;
    QString fileName = QFileDialog::getSaveFileName(this, tr("Save as..."),
        QString(), tr("Output File (*.tree *.TREE *.rules *.RULES);;"), 0);

    if (fileName.isEmpty())
        return;

    boost::filesystem::path outfile(fileName.toUtf8().data());
    m_controller->setOutputFilesPath(outfile);
}
