/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/common/dialogMessageObserver.cpp

  \brief A concrete observer that display Messages in the Graphical User Interface (GUI).

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// Qt Includes
#include <QMessageBox>
#include <QWidget>

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/dialogMessageObserver.hpp"

gdma::guicmp::DialogMessageObserver::DialogMessageObserver(QWidget* parent,
    std::string windowTitle) {
    m_parent = parent;
    m_windowTitle = windowTitle.c_str();
}

gdma::guicmp::DialogMessageObserver::~DialogMessageObserver() {
}

void gdma::guicmp::DialogMessageObserver::displayInformationMsg(std::string msg) {
    QMessageBox::information(m_parent, m_windowTitle, msg.c_str());
}

void gdma::guicmp::DialogMessageObserver::displayWarningMsg(std::string msg) {
    QMessageBox::warning(m_parent, m_windowTitle, msg.c_str());
}

void gdma::guicmp::DialogMessageObserver::displayErrorMsg(std::string msg) {
    QMessageBox::critical(m_parent, m_windowTitle, msg.c_str());
}

void gdma::guicmp::DialogMessageObserver::displayDebugMsg(std::string msg) {
}

void gdma::guicmp::DialogMessageObserver::displayTraceMsg(std::string msg) {
}

void gdma::guicmp::DialogMessageObserver::displayFatalMsg(std::string msg) {
    QMessageBox::critical(m_parent, m_windowTitle, msg.c_str());
}
