/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/kmeansClassificationDialog.hpp

  \brief This file contains the KMeansClassificationDialog class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_GUICMP_KMEANSCLASSIFICATIONDIALOG_HPP_
#define GEODMA_GUICMP_KMEANSCLASSIFICATIONDIALOG_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/widgets/progress/ProgressViewerDialog.h>

// Qt Includes
#include <QDialog>

// STL Includes
#include <list>
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"
#include "geodmalib/guicomponents/kmeans/kmeansClassificationWidget.hpp"

namespace Ui { class GeoDMADialogForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT KMeansClassificationDialog : public QDialog {
    Q_OBJECT

 public:
     explicit KMeansClassificationDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);
     ~KMeansClassificationDialog();

    /*!
        \brief Set the layer that can be used
        \param layers  List of AbstractLayerPtr
    */
    void setLayers(std::list<te::map::AbstractLayerPtr> layers);

    bool newLayerCreated();

    te::map::AbstractLayerPtr getCurrentLayer();

 public slots: //NOLINT
    void onRunPushButtonClicked();
    void onClosePushButtonClicked();

 private:
     std::unique_ptr<Ui::GeoDMADialogForm> m_ui;
     std::unique_ptr<gdma::guicmp::KMeansClassificationWidget> m_kmeansClassificationWidget;

     std::string m_dialogTitle;
     int m_msgObsId;
     int m_progId;
     std::unique_ptr<te::qt::widgets::ProgressViewerDialog> m_progViewer;
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_GUICMP_KMEANSCLASSIFICATIONDIALOG_HPP_
