/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/kmeansClassificationWidget.hpp

  \brief This file contains the KMeansClassificationWidget class definition.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_GUICMP_KMEANSCLASSIFICATIONWIDGET_HPP_
#define GEODMA_GUICMP_KMEANSCLASSIFICATIONWIDGET_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/widgets/utils/DoubleListWidget.h>

// Qt Includes
#include <QWidget>

// STL Includes
#include <list>
#include <memory>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"
#include "geodmalib/guicomponents/kmeans/kmeansClassificationController.hpp"
#include "geodmalib/guicomponents/outputDataWidget.hpp"

namespace Ui { class KMeansClassificationWidgetForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT KMeansClassificationWidget : public QWidget {
    Q_OBJECT

 public:
     explicit KMeansClassificationWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);
     ~KMeansClassificationWidget();

     void setLayers(std::list<te::map::AbstractLayerPtr> layers);

     void setCurrentLayer(te::map::AbstractLayerPtr layer);

     te::map::AbstractLayerPtr getCurrentLayer();

     bool run();

     bool newLayerCreated();

 public slots: //NOLINT
    void onInputLayerComboBoxSelected(int index);

 private:
     std::unique_ptr<Ui::KMeansClassificationWidgetForm> m_ui;  //!< User interface
     std::unique_ptr<te::qt::widgets::DoubleListWidget> m_featuresWidget;
     std::unique_ptr<gdma::guicmp::OutputDataWidget> m_outputWidget;

     std::list<te::map::AbstractLayerPtr> m_vectorLayers;  //!< All vector layers of the application
     gdma::guicmp::KmeansClassificationController m_controller;
};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_GUICMP_KMEANSCLASSIFICATIONWIDGET_HPP_
