/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/layerUtils.cpp

  \brief This file contains the the implementation of some useful functions to deal with TerraLib
         layers.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// TerraLib Includes
#include <terralib/core/translator/Translator.h>
#include <terralib/dataaccess/datasource/DataSource.h>
#include <terralib/dataaccess/datasource/DataSourceInfo.h>
#include <terralib/dataaccess/utils/Utils.h>
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/widgets/layer/utils/DataSet2Layer.h>

// Boost Includes
#include <boost/filesystem.hpp>

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/common/messageMediator.hpp"
#include "geodmalib/datamanager/dataManager.hpp"
#include "geodmalib/guicomponents/layerUtils.hpp"

te::map::AbstractLayerPtr gdma::guicmp::createTerraLibLayer(const std::string pathToFile,
    const std::string layerName) {
    te::da::DataSourceInfoPtr dsInfo = gdma::dm::openDataSource(pathToFile);
    te::da::DataSourcePtr outDataSource = te::da::GetDataSource(dsInfo->getId());
    te::qt::widgets::DataSet2Layer converter(dsInfo->getId());
    te::da::DataSetTypePtr dt =
        outDataSource->getDataSetType(boost::filesystem::basename(pathToFile));
    te::map::AbstractLayerPtr out_layer = converter(dt);
    out_layer->setTitle(layerName);

    return out_layer;
}

bool gdma::guicmp::columnExistsInLayer(const te::map::AbstractLayerPtr layer,
    std::string columnName) {
    te::dt::Property* prop = layer->getSchema()->getProperty(columnName);

    if (prop)
        return true;
    else
        return false;
}
