/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/layerUtils.hpp

  \brief This file contains the the definition of some useful functions to deal with TerraLib
         layers.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_GUICMP_LAYERUTILS_HPP_
#define GEODMA_LIB_GUICMP_LAYERUTILS_HPP_

// TerraLib Includes
#include <terralib/maptools/AbstractLayer.h>

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"

namespace gdma {
namespace guicmp {
/*!
    \brief Create a new TerraLib layer.
    \param[in] pathToFile Path to the shape file being used to create the layer
    \param[in] layerName The name of the layer in the Application.
    \return A pointer to the layer created.
*/
GDMAGUICMPEXPORT te::map::AbstractLayerPtr createTerraLibLayer(const std::string pathToFile,
    const std::string layerName);

/*!
    \brief Verify if a given column exists in the dataset corresponding to a given layer.
    \param[in] layer The input layer
    \param[in] columnName The column name to be verifyed.
    \return True if the column exists, false otherwise.
*/
GDMAGUICMPEXPORT bool columnExistsInLayer(const te::map::AbstractLayerPtr layer,
    std::string columnName);
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_LIB_GUICMP_LAYERUTILS_HPP_
