/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
\file gdma/lib/guicomponents/multiSelectionTool.hpp

\brief This file contains the MultiSelectionTool class definition.

\author Raian Vargas Maretto
\author Thales Sehn Korting
\author Emiliano Ferreira Castejon
*/

// TerraLib Includes
#include <terralib/qt/widgets/canvas/MapDisplay.h>
#include <terralib/maptools/AbstractLayer.h>
#include <terralib/qt/widgets/tools/RubberBand.h>

// Qt Includes
#include <QCursor>

// STL Includes
#include <list>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT MultiSelectionTool : public te::qt::widgets::RubberBand {
    Q_OBJECT

 public:
    /** @name Initializer Methods
      * Methods related to instantiation and destruction.
      */
    //@{

    /*!
      \brief It constructs a selection tool associated with the given map display.

      \param display The map display associated with the tool.
      \param cursor The tool cursor.
      \param layer The layer list that will be selected.
      \param parent The tool's parent.

      \note The tool will NOT take the ownership of the given pointers.
    */
    MultiSelectionTool(te::qt::widgets::MapDisplay* display, const QCursor& cursor,
        const std::list<te::map::AbstractLayerPtr>& layers, QObject* parent = 0);

    /*! \brief Destructor. */
    ~MultiSelectionTool();

    //@}
    /** @name AbstractTool Methods
    *  Methods related with tool behavior.
    */
    //@{
    bool mousePressEvent(QMouseEvent* e);
    bool mouseMoveEvent(QMouseEvent* e);
    bool mouseReleaseEvent(QMouseEvent* e);
    //@}

 public slots: //NOLINT
    void setLayers(const std::list<te::map::AbstractLayerPtr>& layers);

 protected:
    void executeSelection(const te::map::AbstractLayerPtr& layer, const te::gm::Envelope& e);

 signals:  //NOLINT
    /*! This signal is emitted when the layer selection changed. */
    void layerSelectedObjectsChanged(const te::map::AbstractLayerPtr& layer);

 protected:
     std::list<te::map::AbstractLayerPtr> m_layers;  //!< The layer list that will be selected.
     bool m_selectionStarted;  //!< Flag that indicates if selection operation was started.
     bool m_keepPreviousSelection;  //!< Flag that indicates if the tool must keep the previous selection.
     bool m_selectionByPointing;  //!< Flag that indicates if the selection is by pointing.
};
}  // namespace guicmp
}  // namespace gdma
