/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/guicomponents/outputDataWidget.hpp

  \brief This file contains the OutputDataWidget class implementation.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// QT Includes
#include <QString>
#include <QWidget>

// STL Includes
#include <memory>
#include <string>

// GeoDMA Includes
#include "geodmalib/guicomponents/config.hpp"

namespace Ui { class OutputDataWidgetForm; }

#ifndef GEODMA_LIB_GUICMP_OUTPUTDATAWIDGET_HPP_
#define GEODMA_LIB_GUICMP_OUTPUTDATAWIDGET_HPP_

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT OutputDataWidget : public QWidget {
    Q_OBJECT

 public:
    explicit OutputDataWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~OutputDataWidget();

    std::string getCurrentLayerName();

    void setCurrentLayerName(std::string layerName);

    std::string getCurrentSHPPath();

    void setCurrentSHPPath(std::string shpPath);

    std::string getCurrentCSVPath();

    void setCurrentCSVPath(std::string csvPath);

 public slots:  //NOLINT
    void onSHPTargetFileToolButtonPressed();
    void onCSVTargetFileToolButtonPressed();
    void onOutLayerNameLineEditChanged(QString);

 private:
    std::unique_ptr<Ui::OutputDataWidgetForm> m_ui;
    QString m_currentLayerName;
    QString m_currentSHPPath;
    QString m_currentCSVPath;
};
}  // namespace guicmp
}  // namespace gdma
#endif  // GEODMA_LIB_GUICMP_OUTPUTDATAWIDGET_HPP_
