/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/semanticanalysis/SemanticAnalysisWidget.hpp

  \brief This file contains the SemanticAnalysisWidget class definition.
*/

#ifndef GEODMA_TVPLUGIN_SEMANTICANALYSISWIDGET_HPP_
#define GEODMA_TVPLUGIN_SEMANTICANALYSISWIDGET_HPP_

#include "../config.hpp"
#include "../../semanticanalysis/localExecuter.hpp"
#include "../../semanticanalysis/project.hpp"
#include "../../semanticanalysis/executerCallBack.hpp"

#include <QWidget>
#include <QTimer>

#include <memory>
#include <mutex>

namespace Ui { class SemanticAnalysisWidgetForm; }

namespace gdma {
namespace guicmp {
class GDMAGUICMPEXPORT SemanticAnalysisWidget : public QWidget,
  protected gdma::sa::ExecuterCallBack {
    Q_OBJECT

 public:
    /*!
      \enum ExecuterStatus Executer status.
    */
    enum ExecuterStatus {
      INACTIVE_EXECUTER,  //!< Inactive executer.
      ACTIVE_EXECUTER  //!< Executer active.
    };

   explicit SemanticAnalysisWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);

    ~SemanticAnalysisWidget();

    ExecuterStatus getExecuterStatus() const;

   signals:

 protected:
   std::unique_ptr<Ui::SemanticAnalysisWidgetForm> m_uiPtr;
   gdma::sa::Project m_project;
   QTimer m_timer;
   gdma::sa::LocalExecuter m_executer;
   unsigned int m_executedTasksNumber;
   unsigned int m_totalTasksNumber;
   std::mutex m_mutex;

   void closeEvent(QCloseEvent* e);

   //  overload
   void verticeTaskStarted( const std::string& analysisName,
     const std::string& graphName, const std::string& verticeName );

   //  oveload
   void verticeTaskExecuted( const std::string& analysisName,
     const std::string& graphName, const std::string& verticeName,
     const gdma::tp::TaskExecutionResult::BasicResult& basicResut );

 protected slots: //NOLINT
    void onNewPushButtonClicked();

    void onOpenPushButtonClicked();

    void onSavePushButtonClicked();

    void onStartPushButtonClicked();

    void onStopPushButtonClicked();

    void onStepPushButtonClicked();

    void onContextsPushButtonClicked();

    void onAnalysisPushButtonClicked();

    void onTimerTimeOut();

    void updateAllAnalysisDraw( bool recreateTabs );

 private:

};
}  // namespace guicmp
}  // namespace gdma

#endif  // GEODMA_TVPLUGIN_SEMANTICANALYSISWIDGET_HPP_
