/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/defines.hpp

  \brief GeoDMA Semantic Analysis module defines.
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_INTERNAL_DEFINES_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_INTERNAL_DEFINES_HPP_

  #include <terralib/datatype.h>

  #include <limits>
  #include <cstdint>

  /*!
    \brief The default terralib raster type to use when creating raster objects.
  */
  #define GDMA_SA_DEF_TL_RASTER_DATA_TYPE te::dt::INT32_TYPE

  /*!
    \brief The default basic data type to deal with classes IDs (numeric values).
  */
  #define GDMA_SA_DEFAULT_CLASS_ID_TYPE std::int32_t

  /*!
    \brief The default class name property name used when with datasets.
  */
  #define GDMA_SA_DEFAULT_CLASSNAME_PROP_NAME "GSA_CLNA"

  /*!
    \brief The default class ID property name used when with datasets.
  */
  #define GDMA_SA_DEFAULT_CLASSID_PROP_NAME "GSA_CLID"

  /*!
    \brief The default geometry property name used when dealing with datasets.
  */
  #define GDMA_SA_DEFAULT_GEOM_PROP_NAME "OGR_GEOMETRY"

  /*!
    \brief The default class name for unknown classes.
  */
  #define GDMA_SA_DEFAULT_UNKNOWN_CLASS_NAME "UNKNOWN"

  /*!
    \brief The default class name for invalid classes.
  */
  #define GDMA_SA_DEFAULT_INVALID_CLASS_NAME "INVALID"

  /*!
    \brief The default class ID (numeric value) for invalid classes.
  */
  #define GDMA_SA_DEFAULT_INVALID_CLASS_ID 0

  /*!
    \brief The default class ID (numeric value) for unknown classes.
  */
  #define GDMA_SA_DEFAULT_UNKNOWN_CLASS_ID std::numeric_limits<GDMA_SA_DEFAULT_CLASS_ID_TYPE>::max()

#endif  // GEODMA_LIB_SEMANTICANALYSIS_INTERNAL_DEFINES_HPP_

