/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/executerCallBack.hpp
  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_EXECUTERCALLBACK_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_EXECUTERCALLBACK_HPP_

#include <string>

// GeoDMA Includes
#include "config.hpp"
#include "../taskprocessing/taskExecutionResult.hpp"

namespace gdma {
namespace sa {

/*!
  \class ExecuterCallBack

  \brief A basic concept of a task executer callback.
*/
class GDMASEMANTICANALYSISEXPORT ExecuterCallBack {
 public:
    /*! \brief Default destructor. */
    virtual ~ExecuterCallBack();

    /*!
      \brief Called each time a vertice task has started.
      \param analysisName Analysis name.
      \param graphName Graph name.
      \param verticeName Vertice name.
    */
    virtual void verticeTaskStarted( const std::string& analysisName,
      const std::string& graphName, const std::string& verticeName ) = 0;

    /*!
      \brief Called each time a vertice task has finished.
      \param analysisName Analysis name.
      \param graphName Graph name.
      \param verticeName Vertice name.
    */
    virtual void verticeTaskExecuted( const std::string& analysisName,
      const std::string& graphName, const std::string& verticeName,
      const gdma::tp::TaskExecutionResult::BasicResult& basicResut ) = 0;

 protected:
    /*! \brief Default constructor. */
    ExecuterCallBack();

    /*! \brief Default constructor. */
    ExecuterCallBack(const ExecuterCallBack&);
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_EXECUTERCALLBACK_HPP_
