/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/executionResult.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_EXECUTIONRESULT_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_EXECUTIONRESULT_HPP_

#include <string>

// GeoDMA Includes
#include "config.hpp"
#include "../taskprocessing/taskExecutionResult.hpp"

namespace gdma {
namespace sa {

/*!
  \class ExecutionResult

  \brief A basic concept of a Execution Result.
*/
class GDMASEMANTICANALYSISEXPORT ExecutionResult : public gdma::tp::TaskExecutionResult {
 public:
    /*! \brief Default constructor. */
    ExecutionResult();

    /*! \brief Default destructor. */
    ~ExecutionResult();

    //  overload
    TaskExecutionResult* clone() const;

    /*!
      \brief Returns the current error message.
      \return Returns the current error message.
     */
    const std::string& getErrorMessage() const;

    /*!
      \brief Set the current error message.
      \param errorMessage The new error message.
     */
    void setErrorMessage( const std::string& errorMessage );

 protected:
    /*! \brief Default constructor. */
    ExecutionResult(const ExecutionResult& other);

    ExecutionResult& operator=( const ExecutionResult& other );

 private:
    /*! \brief Error message. */
    std::string m_errorMessage;
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_EXECUTIONRESULT_HPP_
