/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/featuresVertice.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_FEATURESVERTICE_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_FEATURESVERTICE_HPP_

#include <terralib/core.h>

#include <string>
#include <map>
#include <utility>
#include <vector>

#include "config.hpp"
#include "graphVertice.hpp"
#include "graphVerticeFactory.hpp"

namespace gdma {
namespace sa {

/*!
  \class FeaturesVertice

  \brief A vertice to generate features.
*/
class GDMASEMANTICANALYSISEXPORT FeaturesVertice : public GraphVertice {
 public:
    FeaturesVertice();

    FeaturesVertice(const FeaturesVertice& other);

    ~FeaturesVertice();

    FeaturesVertice& operator=( const FeaturesVertice& other );

    //  overload
    std::string getType() const;

    //  overload
    void getDescription( std::string& descriptionStr ) const;

    //  overload
    bool setParameter( const std::string& parameterName,
      const std::string& parameterValue );

    //  overload
    void getParameters( std::vector< std::pair< std::string, std::string > >& parameters ) const;

    //  overload
    bool setResource( const std::string& contextURIAlias,
      const std::string& verticeURIAlias );

    //  overload
    void getInParsDescription( std::map< std::string, std::string >& inParsDesc ) const;

    //  overload
    void getInResDescription( std::map< std::string, std::string >& inResDesc ) const;

    //  overload
    OutputType getOutputType() const;

    //  overload
    GraphVertice* clone() const;

    //  overload
    bool isConnectable( const GraphVertice& other, const std::string& alias ) const;

    //  overload
    bool isMultiClass() const;

    //  overload
    bool is2ndPassCapable() const;

 protected:
    /*! \brief Enable/disable the calcule of spectral features. */
    bool m_enableSpectralFeatures;

    /*! \brief Enable/disable the calcule of spatial features. */
    bool m_enableSpatialFeatures;

    /*! \brief Enable/disable the calcule of landscape features. */
    bool m_enableLandscapeFeatures;

    /*! \brief Input image URI. */
    te::core::URI m_inputImageURI;

    /*! \brief Finer vectors URI. */
    te::core::URI m_inputFinerVectorsURI;

    /*! \brief Finer vectors class property name. */
    std::string m_finerVectorsClassPropertyName;

    /*!
      \brief Reset this vertice to its initial state.
    */
    void reset();

    //  overload
    bool executeFirstPass( std::string& errorMessage );
};

class FeaturesVerticeFactory : public GraphVerticeFactory {
 public:
    FeaturesVerticeFactory();
    ~FeaturesVerticeFactory();

 protected:
    // overload
    GraphVertice* build();
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_FEATURESVERTICE_HPP_
