/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/graphVerticeFactory.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_GRAPHVERTICEFACTORY_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_GRAPHVERTICEFACTORY_HPP_

#include <string>
#include <functional>

// GeoDMA Includes
#include "config.hpp"
#include "../common/abstractFactory.hpp"

namespace gdma {
namespace sa {

// forward
class GraphVertice;

/*!
  \class GraphVerticeFactory

  \brief A basic concept of a GraphVertice Factory.

  \note The factory key = the graph vertice type.
*/
class GDMASEMANTICANALYSISEXPORT GraphVerticeFactory : public gdma::common::AbstractFactory<GraphVertice, std::string, std::less<std::string> >{
 public:
    /*! \brief Default destructor. */
    virtual ~GraphVerticeFactory();

 protected:
    /*! \brief Default constructor. */
    explicit GraphVerticeFactory(const std::string& factoryKey);
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_GRAPHVERTICEFACTORY_HPP_
