/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/projectIO.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_PROJECTIO_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_PROJECTIO_HPP_

#include <string>

// GeoDMA Includes
#include "config.hpp"
#include "project.hpp"

namespace gdma {
namespace sa {

/*!
  \class ProjectIO

  \brief A basic concept of a Project IO.
*/
class GDMASEMANTICANALYSISEXPORT ProjectIO {
 public:
    /*!
      \brief Load a project file.
      \param fileName Project file name.
      \param proj Loaded project.
      \param errorMessage Error message (if there is any).
      \return true if ok, false on errors.
    */
    virtual bool load( const std::string& fileName, Project& proj,
      std::string& errorMessage ) const = 0;

    /*!
      \brief Save a project file.
      \param fileName Project file name.
      \param proj Loaded project.
      \param errorMessage Error message (if there is any).
      \return true if ok, false on errors.
    */
    virtual bool save( const Project& proj, const std::string& fileName,
      std::string& errorMessage ) const = 0;

 protected:
    ProjectIO() {}

 private:
    ProjectIO( const ProjectIO& ) {}

    ProjectIO& operator=( const ProjectIO& ) { return *this; }
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_PROJECTIO_HPP_
