/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

// GeoDMA Includes
#include "projectIOFactory.hpp"

// Terralib
#include <terralib/common/StringUtils.h>

// Boost
#include <boost/filesystem.hpp>

#include <string>
#include <memory>
#include <functional>

namespace gdma {
namespace sa {

  ProjectIOFactory::ProjectIOFactory(const std::string& factoryKey)
  : gdma::common::AbstractFactory<ProjectIO, std::string, std::less<std::string> >(factoryKey)
  {
  }

  ProjectIOFactory::~ProjectIOFactory()
  {
  }

  bool ProjectIOFactory::load( const std::string& fileName, Project& proj, std::string& errorMessage )
  {
    std::string extension = te::common::Convert2UCase(
      boost::filesystem::path( fileName ).extension().string() );

    if( extension.empty() )
    {
      return false;
    }
    else
    {
      if( extension[ 0 ] == '.' )
      {
        extension = extension.substr( 1, extension.size() - 1 );
      }

      ProjectIOFactory* factoryPtr = static_cast<ProjectIOFactory*>(
        gdma::common::AbstractFactory<ProjectIO, std::string>::getDictionary().find(
        extension));

      if( factoryPtr )
      {
        std::unique_ptr< ProjectIO > ioPtr( factoryPtr->make( extension ) );

        return ioPtr->load( fileName, proj, errorMessage );
      }
      else
      {
        return false;
      }
    }
  }

  bool ProjectIOFactory::save( const Project& proj, const std::string& fileName,
    std::string& errorMessage )
  {
    std::string extension = te::common::Convert2UCase(
      boost::filesystem::path( fileName ).extension().string() );

    if( extension.empty() )
    {
      return false;
    }
    else
    {
      if( extension[ 0 ] == '.' )
      {
        extension = extension.substr( 1, extension.size() - 1 );
      }

      ProjectIOFactory* factoryPtr = static_cast<ProjectIOFactory*>(
        gdma::common::AbstractFactory<ProjectIO, std::string>::getDictionary().find(
        extension));

      if( factoryPtr )
      {
        std::unique_ptr< ProjectIO > ioPtr( factoryPtr->make( extension ) );

        return ioPtr->save( proj, fileName, errorMessage );
      }
      else
      {
        return false;
      }
    }
  }
}  // end namespace sa
}  // end namespace gdma
