/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/projectIOFactory.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_PROJECTIOFACTORY_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_PROJECTIOFACTORY_HPP_

#include <string>
#include <functional>

// GeoDMA Includes
#include "config.hpp"
#include "projectIO.hpp"
#include "../common/abstractFactory.hpp"

namespace gdma {
namespace sa {

/*!
  \class ProjectIOFactory

  \brief A basic concept of a Project IO Factory.

  \note The factory key = the file extension.
*/
class GDMASEMANTICANALYSISEXPORT ProjectIOFactory : public gdma::common::AbstractFactory<ProjectIO, std::string, std::less<std::string> >{
 public:
    /*! \brief Default destructor. */
    virtual ~ProjectIOFactory();

    /*!
      \brief Load a project file.
      \param fileName Project file name.
      \param proj Loaded project.
      \param errorMessage Error message (if there is any).
      \return true if ok, false on errors.
    */
    static bool load( const std::string& fileName, Project& proj,
      std::string& errorMessage );

    /*!
      \brief Save a project file.
      \param fileName Project file name.
      \param proj Loaded project.
      \param errorMessage Error message (if there is any).
      \return true if ok, false on errors.
    */
    static bool save( const Project& proj, const std::string& fileName,
      std::string& errorMessage );

 protected:
    /*! \brief Default constructor. */
    explicit ProjectIOFactory(const std::string& factoryKey);
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_PROJECTIOFACTORY_HPP_
