/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/rasterFunctions.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_RASTERFUNCTIONS_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_RASTERFUNCTIONS_HPP_

#include <boost/ptr_container/ptr_vector.hpp>
//
#include <terralib/geometry.h>
#include <terralib/raster.h>
// #include <terralib/core.h>
//
#include <string>
#include <memory>
#include <vector>
#include <map>

// GeoDMA Includes
#include "config.hpp"
#include "typedefs.hpp"

namespace gdma {
namespace sa {

  /*!
    \brief Vectorize a result raster.
    \param inputRaster Input raster.
    \param vectors Output vectors.
    \param vectorsIDsPtr A pointer to a vector of IDs or an null pointer.
    \return true if ok, false on errors.
    \note Only Polygons are processed.
    */
  GDMASEMANTICANALYSISEXPORT bool vectorizeResultRaster(
    const te::rst::Raster& inputRaster,
    boost::ptr_vector< te::gm::Geometry >& vectors,
    std::vector< GraphVerticeIDT >* vectorsIDsPtr );

  /*!
    \brief Vectorize a result raster.
    \param inputRasterFileName Result raster file name.
    \param vectors Output vectors.
    \param vectorsIDsPtr A pointer to a vector of IDs or an null pointer.
    \return true if ok, false on errors.
    \note Only Polygons are processed.
    */
  GDMASEMANTICANALYSISEXPORT bool vectorizeResultRaster(
    const std::string& inputRasterFileName,
    boost::ptr_vector< te::gm::Geometry >& vectors,
    std::vector< GraphVerticeIDT >* vectorsIDsPtr );

    /*!
      \brief Clip and reproject a raster to follow the required targets.
      \param inputRaster Input raster.
      \param targetAreaPtr A pointer to a arget area (under the target SRID) or zero if the entire raster must be used.
      \param targetSRID The target SRID.
      \param outputRaster Output raster pointer.
      \return true if ok, false on errors
    */
  GDMASEMANTICANALYSISEXPORT bool clipAndReprojectRaster(
    const te::rst::Raster& inputRaster, te::gm::Envelope const * const targetAreaPtr,
    int& targetSRID, std::unique_ptr< te::rst::Raster >& outputRasterPtr );


}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_RASTERFUNCTIONS_HPP_
