/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/selectVertice.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_SELECTVERTICE_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_SELECTVERTICE_HPP_

#include <string>
#include <map>
#include <utility>
#include <vector>

#include "config.hpp"
#include "graphVertice.hpp"
#include "graphVerticeFactory.hpp"

namespace gdma {
namespace sa {

/*!
  \class SelectVertice

  \brief A vertice capable of executing a SQL query over the input vertices results.
*/
class GDMASEMANTICANALYSISEXPORT SelectVertice : public GraphVertice {
 public:
    SelectVertice();

    SelectVertice(const SelectVertice& other);

    ~SelectVertice();

    SelectVertice& operator=( const SelectVertice& other );

    //  overload
    std::string getType() const;

    //  overload
    void getDescription( std::string& descriptionStr ) const;

    //  overload
    bool setParameter( const std::string& parameterName,
      const std::string& parameterValue );

    //  overload
    void getParameters( std::vector< std::pair< std::string, std::string > >& parameters ) const;

    //  overload
    bool setResource( const std::string& contextURIAlias,
      const std::string& verticeURIAlias );

    //  overload
    void getInParsDescription( std::map< std::string, std::string >& inParsDesc ) const;

    //  overload
    void getInResDescription( std::map< std::string, std::string >& inResDesc ) const;

    //  overload
    OutputType getOutputType() const;

    //  overload
    GraphVertice* clone() const;

    //  overload
    bool isConnectable( const GraphVertice& other, const std::string& alias ) const;

    //  overload
    bool isMultiClass() const;

    //  overload
    bool is2ndPassCapable() const;

 protected:
    /*! \brief SELECT WHERE clause. */
    std::string m_selectWhereClause;

    /*!
      \brief Reset this vertice to its initial state.
       \note THIS IS NOT A THREAD SAFE METHOD
    */
    void reset();

    //  overload
    bool executeFirstPass( std::string& errorMessage );
};

class SelectVerticeFactory : public GraphVerticeFactory {
 public:
    SelectVerticeFactory();
    ~SelectVerticeFactory();

 protected:
    // overload
    GraphVertice* build();
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_SELECTVERTICE_HPP_
