/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/semanticanalysis/verticeTask.hpp
*/

#ifndef GEODMA_LIB_SEMANTICANALYSIS_VERTICETASK_HPP_
#define GEODMA_LIB_SEMANTICANALYSIS_VERTICETASK_HPP_

#include <memory>

// GeoDMA Includes
#include "config.hpp"
#include "executionResult.hpp"
#include "../taskprocessing/task.hpp"

namespace gdma {
namespace sa {

/*!
  \class VerticeTask

  \brief A basic concept of a Vertice Task.
*/
class GDMASEMANTICANALYSISEXPORT VerticeTask : public gdma::tp::Task {
 public:
    /*! \brief Default destructor. */
    virtual ~VerticeTask();

    //  overload
    const gdma::tp::TaskExecutionResult& getExecutionResult() const;

    /*!
      \brief Returns the execution result (constant).
      \return Returns the execution result (constant).
    */
    const ExecutionResult& getVerticeTaskExecResult() const;

 protected:
    VerticeTask();

    /*!
      \brief Set the task execution result.
      \param execResult The new task execution result.
    */
    void setExecResult( const ExecutionResult& execResult );

 private:
    VerticeTask( const VerticeTask& other );

    /*! \brief Vertice execution result */
    std::unique_ptr< ExecutionResult > m_execResultPtr;
};

}  // end namespace sa
}  // end namespace gdma

#endif  // GEODMA_LIB_SEMANTICANALYSIS_VERTICETASK_HPP_
