/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/taskprocessing/executercallback.hpp
  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_TASKPROCESSING_EXECUTERCALLBACK_HPP_
#define GEODMA_LIB_TASKPROCESSING_EXECUTERCALLBACK_HPP_

// GeoDMA Includes
#include "config.hpp"
#include "defines.hpp"
#include "taskExecutionResult.hpp"

namespace gdma {
namespace tp {

/*!
  \class ExecuterCallBack

  \brief A basic concept of a task executer callback.
*/
class GDMATASKPROCESSINGEXPORT ExecuterCallBack {
 public:
    /*! \brief Default destructor. */
    virtual ~ExecuterCallBack();

    /*!
      \brief Called each time a task execution has started.
      \param taskId The task Id.
    */
    virtual void taskStarted(const TaskIdType& taskId) = 0;

    /*!
      \brief Called each time a task execution has finished.
      \param taskId The task Id.
    */
    virtual void taskExecuted(const TaskIdType& taskId,
      const TaskExecutionResult::BasicResult& basicResut ) = 0;

 protected:
    /*! \brief Default constructor. */
    ExecuterCallBack();

    /*! \brief Default constructor. */
    ExecuterCallBack(const ExecuterCallBack&);
};

}  // end namespace tp
}  // end namespace gdma

#endif  // GEODMA_LIB_TASKPROCESSING_EXECUTERCALLBACK_HPP_
