/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/taskprocessing/task.hpp
  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_TASKPROCESSING_TASK_HPP_
#define GEODMA_LIB_TASKPROCESSING_TASK_HPP_

// GeoDMA Includes
#include "config.hpp"

namespace gdma {
namespace tp {

class TaskExecutionResult;

/*!
  \class Task

  \brief A basic concept of a task.
*/
class GDMATASKPROCESSINGEXPORT Task {
 public:
    /*! \brief Default destructor. */
    virtual ~Task();

    /*!
      \brief The task execution code (will be implemented on each task).
    */
    virtual void execute() = 0;

    /*!
      \brief Returns the execution result (constant).
      \return Returns the execution result (constant).
    */
    virtual const TaskExecutionResult& getExecutionResult() const = 0;

 protected:
    /*! \brief Default constructor. */
    Task();

 private:
    /*! \brief Default constructor. */
    Task(const Task& task);
};

}  // end namespace tp
}  // end namespace gdma

#endif  // GEODMA_LIB_TASKPROCESSING_TASK_HPP_
