/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/lib/taskprocessing/taskexecutionresult.hpp
  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

#ifndef GEODMA_LIB_TASKPROCESSING_TASKEXECUTIONRESULT_HPP_
#define GEODMA_LIB_TASKPROCESSING_TASKEXECUTIONRESULT_HPP_

// GeoDMA Includes
#include "config.hpp"

namespace gdma {
namespace tp {

/*!
  \class TaskExecutionResult

  \brief A basic concept of a task execution result.
*/
class GDMATASKPROCESSINGEXPORT TaskExecutionResult {
 public:
    /*!
      \enum Basic task execution results.
    */
    enum BasicResult {
      INVALID,  //!< Invalid Basic Result (default).
      SUCCESS,  //!< Task executed with sucess.
      FAILED  //!< Task execution failed.
    };

    TaskExecutionResult();

    virtual ~TaskExecutionResult();

    /*!
      \brief Returns the basic result.
      \return Returns the basic result.
    */
    BasicResult getBasicResult() const;

    /*!
      \brief Set the basic result.
      \param newBasicResult The new basic result value.
    */
    void setBasicResult(const BasicResult newBasicResult);

    /*!
      \brief Create a clone of this instance.
      \return A clone of this instance (the caller of this method must take the ownership of the returned object).
    */
    virtual TaskExecutionResult* clone() const;

 protected:
    TaskExecutionResult(const TaskExecutionResult&);
    TaskExecutionResult& operator=( const TaskExecutionResult& other );

 private:
    BasicResult m_basicResult;  //!< Basic execution result.
};

}  // end namespace tp
}  // end namespace gdma

#endif  // GEODMA_LIB_TASKPROCESSING_TASKEXECUTIONRESULT_HPP_
