/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/tests/unittest/common/messageMediator_unittest.cpp

  \brief This file contains unit tests for the MessageMediator class

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// GTest includes
#include <gtest/gtest.h>

// STL Includes
#include <string>

// GeoDMA includes
#include "geodmalib/common/commandLineMsgObserver.hpp"

TEST(CommandLineMsgObserver, displayInformationMsg) {
    testing::internal::CaptureStdout();

    gdma::common::CommandLineMsgObserver cmdObs;
    cmdObs.displayInformationMsg("Information Message");

    std::string output = testing::internal::GetCapturedStdout();

    std::ostringstream outputTemplate;
    outputTemplate << "Information Message" << std::endl;

    EXPECT_STRCASEEQ(outputTemplate.str().c_str(), output.c_str());
}

TEST(CommandLineMsgObserver, displayWarningMsg) {
    testing::internal::CaptureStdout();

    gdma::common::CommandLineMsgObserver cmdObs;
    cmdObs.displayWarningMsg("Warning Message");

    std::string output = testing::internal::GetCapturedStdout();

    std::ostringstream outputTemplate;
    outputTemplate << "WARNING: Warning Message" << std::endl;

    EXPECT_STRCASEEQ(outputTemplate.str().c_str(), output.c_str());
}

TEST(CommandLineMsgObserver, displayErrorMsg) {
    testing::internal::CaptureStdout();

    gdma::common::CommandLineMsgObserver cmdObs;
    cmdObs.displayErrorMsg("Error Message");

    std::string output = testing::internal::GetCapturedStdout();

    std::ostringstream outputTemplate;
    outputTemplate << "ERROR: Error Message" << std::endl;

    EXPECT_STRCASEEQ(outputTemplate.str().c_str(), output.c_str());
}

TEST(CommandLineMsgObserver, displayDebugMsg) {
    testing::internal::CaptureStdout();

    gdma::common::CommandLineMsgObserver cmdObs;
    cmdObs.displayDebugMsg("Debug Message");

    std::string output = testing::internal::GetCapturedStdout();

    std::ostringstream outputTemplate;
    outputTemplate << "<DEBUG>: Debug Message" << std::endl;

    EXPECT_STRCASEEQ(outputTemplate.str().c_str(), output.c_str());
}

TEST(CommandLineMsgObserver, displayTraceMsg) {
    testing::internal::CaptureStdout();

    gdma::common::CommandLineMsgObserver cmdObs;
    cmdObs.displayTraceMsg("Trace Message");

    std::string output = testing::internal::GetCapturedStdout();

    std::ostringstream outputTemplate;
    outputTemplate << "<TRACE>: Trace Message" << std::endl;

    EXPECT_STRCASEEQ(outputTemplate.str().c_str(), output.c_str());
}

TEST(CommandLineMsgObserver, displayFatalMsg) {
    testing::internal::CaptureStdout();

    gdma::common::CommandLineMsgObserver cmdObs;
    cmdObs.displayFatalMsg("Fatal Message");

    std::string output = testing::internal::GetCapturedStdout();

    std::ostringstream outputTemplate;
    outputTemplate << "FATAL: Fatal Message" << std::endl;

    EXPECT_STRCASEEQ(outputTemplate.str().c_str(), output.c_str());
}
