/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/tests/unittest/datamanager/dataManager_unittest.cpp

  \brief

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// GTest includes
#include <gtest/gtest.h>
#include <gmock/gmock.h>

// TerraLib includes
#include <terralib/common/TerraLib.h>
#include <terralib/common/Exception.h>
#include <terralib/core/plugin.h>

// STL includes
#include <map>
#include <string>
#include <vector>

// GeoDMA Includes
#include "geodmalib/common/utils.hpp"

using ::testing::Between;

class CommonUtilsTest : public ::testing::Test {
 private:
    virtual void SetUp() {
        // Initialize TerraLib
        try {
//             TerraLib::getInstance().initialize();
        }
        catch (te::common::Exception &e) {
            std::cerr << "ERROR: " << e.what() << std::endl;
        }
    }

    virtual void TearDown() {
        // Finilize TerraLib
//         TerraLib::getInstance().finalize();
    }
};

TEST_F(CommonUtilsTest, loadTerraLibDrivers) {
    gdma::common::loadTerraLibDrivers();

    EXPECT_EQ(2, te::core::PluginManager::instance().getPlugins().size());

    EXPECT_TRUE(te::core::PluginManager::instance().isLoaded("te.da.gdal"));
    EXPECT_TRUE(te::core::PluginManager::instance().isLoaded("te.da.ogr"));

    gdma::common::unloadTerraLibDrivers();
}

TEST_F(CommonUtilsTest, unloadTerraLibDrivers) {
    gdma::common::loadTerraLibDrivers();

    EXPECT_EQ(2, te::core::PluginManager::instance().getPlugins().size());

    EXPECT_TRUE(te::core::PluginManager::instance().isLoaded("te.da.gdal"));
    EXPECT_TRUE(te::core::PluginManager::instance().isLoaded("te.da.ogr"));

    gdma::common::unloadTerraLibDrivers();
    EXPECT_EQ(0, te::core::PluginManager::instance().getPlugins().size());

    EXPECT_FALSE(te::core::PluginManager::instance().isLoaded("te.da.gdal"));
    EXPECT_FALSE(te::core::PluginManager::instance().isLoaded("te.da.ogr"));
}

TEST(CommonUtils, formatTime) {
    EXPECT_STREQ("00:00:50", gdma::common::formatTime(50).c_str());
    EXPECT_STREQ("00:01:50", gdma::common::formatTime(110).c_str());
    EXPECT_STREQ("01:00:20", gdma::common::formatTime(3620).c_str());
    EXPECT_STREQ("01:01:50", gdma::common::formatTime(3710).c_str());
    EXPECT_STREQ("27:46:40", gdma::common::formatTime(100000).c_str());
}

TEST(CommonUtils, generateRandomColor) {
    std::map<std::string, int> color = gdma::common::generateRandomColor();

    EXPECT_EQ(4, color.size());
    EXPECT_TRUE(color["red"] >= 0 && color["red"] <= 255);
    EXPECT_TRUE(color["green"] >= 0 && color["green"] <= 255);
    EXPECT_TRUE(color["blue"] >= 0 && color["blue"] <= 255);
    EXPECT_TRUE(color["alpha"] >= 0 && color["alpha"] <= 255);
}

TEST(CommonUtils, generateRandomHexColor) {
    std::string color = gdma::common::generateRandomHexColor();

    EXPECT_EQ(7, color.length());
}
