/*  Copyright (C) 2012 National Institute For Space Research (INPE) - Brazil.

This file is part of the GeoDMA - a Toolbox that integrates Data Mining Techniques with object-based
and multi-temporal analysis of satellite remotely sensed imagery.

GeoDMA is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

GeoDMA is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with GeoDMA. See COPYING. If not, write to
GeoDMA Team at <thales@dpi.inpe.br, raian@dpi.inpe.br, castejon@dpi.inpe.br>.
*/

/*!
  \file gdma/guicomponents/kmeans/layerUtils_unittest.cpp

  \brief This file contains unit tests for the functions that manage layers.

  \author Raian Vargas Maretto
  \author Thales Sehn Korting
  \author Emiliano Ferreira Castejon
*/

// GTest Includes
#include <gtest/gtest.h>

// TerraLib Includes
#include <terralib/common/TerraLib.h>

// STL Includes
#include <string>

// GeoDMA Includes
#include "geodmalib/common/utils.hpp"
#include "geodmalib/common/fileSystem.hpp"
#include "geodmalib/guicomponents/layerUtils.hpp"

class LayerUtilsTest : public ::testing::Test {
 protected:
    virtual void SetUp() {
        try {
//             TerraLib::getInstance().initialize();
//             gdma::common::loadTerraLibDrivers();
        } catch (te::common::Exception &e) {
            std::cerr << "ERROR: " << e.what() << std::endl;
        }
    }

    virtual void TearDown() {
//         gdma::common::unloadTerraLibDrivers();
//         TerraLib::getInstance().finalize();
    }
};

TEST_F(LayerUtilsTest, createTerraLibLayerTest) {
    std::string inputSHP = gdma::common::FindInGeoDMAPath(
        "data/tests/clipped_pols_tests-Samples_Feat.shp");

    te::map::AbstractLayerPtr testLayer;

    ASSERT_NO_THROW({
        testLayer = gdma::guicmp::createTerraLibLayer(inputSHP, "teste");
    });

    EXPECT_EQ("teste", testLayer->getTitle());
}
